@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019, 2021, Oracle and/or its affiliates.
+ * Copyright (c) 2019, 2022, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -28,10 +28,11 @@
 #include <climits>
 #include <map>
 #include <memory>
+#include <unordered_set>
 #include <utility>
 #include <vector>
 
-#include "adminapi/common/async_topology.h"
+#include "modules/adminapi/common/async_topology.h"
 #include "modules/adminapi/common/clone_options.h"
 #include "modules/adminapi/common/common.h"
 #include "modules/adminapi/common/dba_errors.h"
@@ -39,6 +40,7 @@
 #include "modules/adminapi/common/gtid_validations.h"
 #include "modules/adminapi/common/member_recovery_monitoring.h"
 #include "modules/adminapi/common/metadata_storage.h"
+#include "modules/adminapi/common/preconditions.h"
 #include "modules/adminapi/common/provision.h"
 #include "modules/adminapi/common/sql.h"
 #include "modules/adminapi/common/validations.h"
@@ -63,20 +65,23 @@ Cluster_join::Cluster_join(
     Cluster_impl *cluster, mysqlsh::dba::Instance *primary_instance,
     const std::shared_ptr<mysqlsh::dba::Instance> &target_instance,
     const Group_replication_options &gr_options,
-    const Clone_options &clone_options, bool interactive)
+    const Clone_options &clone_options, bool interactive,
+    std::optional<bool> switch_comm_stack)
     : m_cluster(cluster),
       m_primary_instance(primary_instance),
       m_target_instance(target_instance),
       m_gr_opts(gr_options),
       m_clone_opts(clone_options),
-      m_interactive(interactive) {
+      m_interactive(interactive),
+      m_is_switching_comm_stack(switch_comm_stack) {
   // Validate the GR options.
   // Note: If the user provides no group_seeds value, it is automatically
   // assigned a value with the local_address values of the existing cluster
   // members and those local_address values are already validated on the
   // validate_local_address_ip_compatibility method, so we only need to validate
   // the group_seeds value provided by the user.
-  m_gr_opts.check_option_values(m_target_instance->get_version());
+  m_gr_opts.check_option_values(m_target_instance->get_version(),
+                                m_target_instance->get_canonical_port());
 
   m_gr_opts.manual_start_on_boot = m_cluster->get_manual_start_on_boot_option();
 
@@ -115,13 +120,33 @@ void Cluster_join::resolve_local_address(
     Group_replication_options *gr_options,
     const Group_replication_options &user_gr_options,
     checks::Check_type check_type) {
-  std::string hostname = m_target_instance->get_canonical_hostname();
+  std::string communication_stack,
+      hostname = m_target_instance->get_canonical_hostname();
+
+  // During a reboot from complete outage the command does not change the
+  // communication stack unless set via switchCommunicationStack
+  if (check_type == checks::Check_type::JOIN ||
+      check_type == checks::Check_type::REJOIN) {
+    communication_stack = m_cluster->get_communication_stack();
+  } else if (check_type == checks::Check_type::BOOTSTRAP &&
+             !gr_options->communication_stack.is_null()) {
+    communication_stack = gr_options->communication_stack.get_safe();
+  } else {
+    // The default value for communicationStack must be 'mysql' if the target
+    // instance is running 8.0.27+
+    if (m_target_instance->get_version() >=
+        k_mysql_communication_stack_initial_version) {
+      communication_stack = kCommunicationStackMySQL;
+    } else {
+      communication_stack = kCommunicationStackXCom;
+    }
+  }
 
   gr_options->local_address = mysqlsh::dba::resolve_gr_local_address(
       user_gr_options.local_address.get_safe().empty()
           ? gr_options->local_address
           : user_gr_options.local_address,
-      hostname, *m_target_instance->get_sysvar_int("port"),
+      communication_stack, hostname, *m_target_instance->get_sysvar_int("port"),
       !m_already_member && check_type == checks::Check_type::JOIN,
       check_type != checks::Check_type::JOIN);
 
@@ -298,6 +323,49 @@ void Cluster_join::store_cloned_replication_account() const {
       recovery_user, recovery_user_host);
 }
 
+void Cluster_join::store_local_replication_account() const {
+  // Insert the recovery account created for the joining member in all
+  // cluster instances and also itself
+  //
+  // This is required when using clone with waitRecovery zero and the commStack
+  // in use by the Cluster is MySQL.
+  // The reason is that with this commStack when an instance joins the Cluster
+  // the recovery account created for it is set to be used by the replication
+  // channel in all Cluster members and itself. Only when the whole joining
+  // process finishes the command can reconfigure the recovery account in every
+  // single active member of the cluster to use its own GR recovery replication
+  // credentials and not the one that was created for the joining instance.
+  // However, when waitRecovery is zero this cannot be done. To avoid
+  // removeInstance() dropping an account still in use, we must insert it in the
+  // MD schema for every cluster member (similar to what's done in
+  // store_cloned_replication_account()).
+  log_debug("Adding joining member recovery account to metadata");
+  m_cluster->execute_in_members(
+      [this](const std::shared_ptr<Instance> &instance,
+             const Instance_md_and_gr_member &info) {
+        if (info.second.state == mysqlshdk::gr::Member_state::ONLINE) {
+          try {
+            m_cluster->get_metadata_storage()->update_instance_repl_account(
+                instance->get_uuid(), Cluster_type::GROUP_REPLICATION,
+                m_gr_opts.recovery_credentials->user, m_account_host);
+          } catch (const std::exception &e) {
+            log_info(
+                "Failed updating Metatada of '%s' to include the recovery "
+                "account of the joining member",
+                instance->descr().c_str());
+          }
+        }
+        return true;
+      },
+      [](const shcore::Error &, const Instance_md_and_gr_member &) {
+        return true;
+      });
+
+  m_cluster->get_metadata_storage()->update_instance_repl_account(
+      m_target_instance->get_uuid(), Cluster_type::GROUP_REPLICATION,
+      m_gr_opts.recovery_credentials->user, m_account_host);
+}
+
 void Cluster_join::restore_group_replication_account() const {
   // See note in store_cloned_replication_account()
   std::string source_term = mysqlshdk::mysql::get_replication_source_keyword(
@@ -409,6 +477,7 @@ void Cluster_join::configure_cluster_set_member() {
         "* Waiting for the Cluster to synchronize with the PRIMARY Cluster...");
     m_cluster->sync_transactions(*m_primary_instance,
                                  k_clusterset_async_channel_name, 0);
+
     auto cs = m_cluster->get_cluster_set();
 
     auto ar_options = cs->get_clusterset_replication_options();
@@ -439,6 +508,58 @@ void Cluster_join::configure_cluster_set_member() {
   }
 }
 
+void Cluster_join::change_recovery_credentials_all_members(
+    const mysqlshdk::mysql::Auth_options &repl_account,
+    const std::string &repl_account_host) const {
+  auto console = mysqlsh::current_console();
+
+  m_cluster->execute_in_members(
+      [console, repl_account, repl_account_host](
+          const std::shared_ptr<Instance> &instance,
+          const Instance_md_and_gr_member &info) {
+        if (info.second.state == mysqlshdk::gr::Member_state::ONLINE) {
+          try {
+            mysqlshdk::mysql::change_replication_credentials(
+                *instance, repl_account.user, *repl_account.password,
+                mysqlshdk::gr::k_gr_recovery_channel);
+          } catch (const std::exception &e) {
+            current_console()->print_warning(shcore::str_format(
+                "Error updating recovery credentials for %s: %s",
+                instance->descr().c_str(), e.what()));
+          }
+        }
+        return true;
+      },
+      [](const shcore::Error &, const Instance_md_and_gr_member &) {
+        return true;
+      });
+}
+
+void Cluster_join::restore_recovery_account_all_members() const {
+  m_cluster->execute_in_members(
+      [this](const std::shared_ptr<Instance> &instance,
+             const Instance_md_and_gr_member &info) {
+        if (info.second.state == mysqlshdk::gr::Member_state::ONLINE) {
+          try {
+            m_cluster->reset_recovery_password(instance);
+          } catch (const std::exception &e) {
+            // If we can't change the recovery account password for some
+            // reason, we must re-create it
+            log_info(
+                "Unable to reset the recovery password of instance '%s', "
+                "re-creating a new account: %s",
+                instance->descr().c_str(), e.what());
+
+            m_cluster->recreate_replication_user(instance);
+          }
+        }
+        return true;
+      },
+      [](const shcore::Error &, const Instance_md_and_gr_member &) {
+        return true;
+      });
+}
+
 void Cluster_join::check_cluster_members_limit() const {
   const std::vector<Instance_metadata> all_instances =
       m_cluster->get_metadata_storage()->get_all_instances(m_cluster->get_id());
@@ -457,6 +578,32 @@ void Cluster_join::check_cluster_members_limit() const {
   }
 }
 
+void Cluster_join::check_comm_stack_support() {
+  m_comm_stack = m_cluster->get_communication_stack();
+
+  if (m_comm_stack == kCommunicationStackMySQL &&
+      m_target_instance->get_version() <
+          k_mysql_communication_stack_initial_version) {
+    auto console = mysqlsh::current_console();
+    console->print_error("Cannot join instance '" + m_target_instance->descr() +
+                         "' to Cluster: The Group Replication protocol stack "
+                         "in used by the Cluster ('" +
+                         kCommunicationStackMySQL +
+                         "') is not supported in the instance");
+
+    throw shcore::Exception("Unsupported Group Replication protocol stack '" +
+                                std::string(kCommunicationStackMySQL) + "'",
+                            SHERR_DBA_UNSUPPORTED_COMMUNICATION_PROTOCOL);
+  }
+
+  // Set the communication stack protocol to be used only if the target instance
+  // supports it
+  if (m_target_instance->get_version() >=
+      k_mysql_communication_stack_initial_version) {
+    m_gr_opts.communication_stack = m_comm_stack;
+  }
+}
+
 Member_recovery_method Cluster_join::check_recovery_method(
     bool clone_disabled) {
   // Check GTID consistency and whether clone is needed
@@ -547,17 +694,39 @@ void Cluster_join::check_instance_configuration(checks::Check_type type) {
     // if instances are rejoined later the operation may fail because
     // a new group_name started being used.
     m_gr_opts.group_name = m_cluster->get_group_name();
+
+    // group_replication_view_change_uuid might have been persisted by
+    // Cluster.rescan() and the target instance wasn't restarted so the value is
+    // not effective yet. Attempt to read it and if not empty, set it right away
+    // in the GR options to be used
+    if (m_target_instance->get_version() >= k_min_cs_version) {
+      std::string view_change_uuid_persisted =
+          m_target_instance
+              ->get_persisted_value("group_replication_view_change_uuid")
+              .get_safe();
+
+      if (!view_change_uuid_persisted.empty()) {
+        m_gr_opts.view_change_uuid = view_change_uuid_persisted;
+      }
+    }
   }
   if (type != checks::Check_type::JOIN) {
     // Read actual GR configurations to preserve them when rejoining the
     // instance.
-    m_gr_opts.read_option_values(*m_target_instance);
+    m_gr_opts.read_option_values(*m_target_instance,
+                                 m_is_switching_comm_stack.value_or(false));
   }
 
   // Check instance configuration and state, like dba.checkInstance
   // But don't do it if it was already done by the caller
-  ensure_gr_instance_configuration_valid(m_target_instance.get(),
-                                         type == checks::Check_type::JOIN);
+  ensure_gr_instance_configuration_valid(
+      m_target_instance.get(),
+      type == checks::Check_type::JOIN || type == checks::Check_type::REJOIN ||
+          type == checks::Check_type::BOOTSTRAP,
+      !m_clone_opts.recovery_method || type == checks::Check_type::REJOIN
+          ? false
+          : m_clone_opts.recovery_method.get_safe() ==
+                Member_recovery_method::CLONE);
 
   // Validate the lower_case_table_names and default_table_encryption
   // variables. Their values must be the same on the target instance as they
@@ -737,8 +906,16 @@ void Cluster_join::prepare_reboot() {
 
   // Make sure the target instance does not already belong to a different
   // cluster.
-  mysqlsh::dba::checks::ensure_instance_not_belong_to_cluster(
-      *m_target_instance, m_cluster->get_cluster_server(), &m_already_member);
+  try {
+    mysqlsh::dba::checks::ensure_instance_not_belong_to_cluster(
+        m_target_instance, m_cluster->get_cluster_server(),
+        m_cluster->get_id());
+  } catch (const shcore::Exception &exp) {
+    m_already_member =
+        (exp.code() == SHERR_DBA_ASYNC_MEMBER_INCONSISTENT) ||
+        (exp.code() == SHERR_DBA_BADARG_INSTANCE_MANAGED_IN_CLUSTER);
+    if (!m_already_member) throw;
+  }
 
   check_instance_configuration(checks::Check_type::BOOTSTRAP);
 }
@@ -749,34 +926,76 @@ void Cluster_join::prepare_join(
 
   check_cluster_members_limit();
 
+  // Validate the options used
+  validate_add_rejoin_options();
+
   // Make sure there isn't some leftover auto-rejoin active
   m_is_autorejoining = check_auto_rejoining(m_target_instance.get());
 
   // Make sure the target instance does not already belong to a cluster.
   // Unless it's our cluster, in that case we keep adding it since it
   // may be a retry.
-  if (mysqlsh::dba::checks::ensure_instance_not_belong_to_cluster(
-          *m_target_instance, m_cluster->get_cluster_server(),
-          &m_already_member) == TargetType::InnoDBCluster) {
-    throw shcore::Exception::runtime_error(
-        "The instance '" + m_target_instance->descr() +
-        "' is already part of this InnoDB cluster");
+  try {
+    mysqlsh::dba::checks::ensure_instance_not_belong_to_cluster(
+        m_target_instance, m_cluster->get_cluster_server(),
+        m_cluster->get_id());
+  } catch (const shcore::Exception &exp) {
+    m_already_member =
+        (exp.code() == SHERR_DBA_ASYNC_MEMBER_INCONSISTENT) ||
+        (exp.code() == SHERR_DBA_BADARG_INSTANCE_MANAGED_IN_CLUSTER);
+
+    if (exp.code() == SHERR_DBA_BADARG_INSTANCE_MANAGED_IN_CLUSTER)
+      throw shcore::Exception::runtime_error(
+          "The instance '" + m_target_instance->descr() +
+          "' is already part of this InnoDB Cluster");
+
+    if (!m_already_member) throw;
   }
 
+  // Verify whether the instance supports the communication stack in use in the
+  // Cluster and set it in the options handler
+  check_comm_stack_support();
+
   // Pick recovery method and check if it's actually usable
-  // Done last to not request interaction before validations
+  // Done last to not request interaction before validatiopns
   m_clone_opts.recovery_method =
       check_recovery_method(m_cluster->get_disable_clone_option());
 
   // Check for various instance specific configuration issues
   check_instance_configuration(checks::Check_type::JOIN);
+
+  // Validate localAddress
+  if (!m_gr_opts.local_address.is_null()) {
+    validate_local_address_option(*m_gr_opts.local_address,
+                                  m_gr_opts.communication_stack.get_safe(),
+                                  m_target_instance->get_canonical_port());
+  }
 }
 
 bool Cluster_join::prepare_rejoin(bool *out_uuid_mistmatch) {
+  // Validate the options used
+  validate_add_rejoin_options();
+
   m_is_autorejoining = check_auto_rejoining(m_target_instance.get());
 
   if (!check_rejoinable(out_uuid_mistmatch)) return false;
 
+  // Verify whether the instance supports the communication stack in use in the
+  // Cluster and set it in the options handler
+  check_comm_stack_support();
+
+  // Check if the Cluster's communication stack has switched
+  if (!m_is_switching_comm_stack.has_value()) {
+    std::string persisted_comm_stack =
+        m_target_instance
+            ->get_sysvar_string("group_replication_communication_stack")
+            .get_safe(kCommunicationStackXCom);
+
+    if (persisted_comm_stack != m_comm_stack) {
+      m_is_switching_comm_stack = true;
+    }
+  }
+
   // Check for various instance specific configuration issues
   check_instance_configuration(checks::Check_type::REJOIN);
 
@@ -800,6 +1019,45 @@ bool Cluster_join::create_replication_user() {
   return false;
 }
 
+void Cluster_join::create_local_replication_user() {
+  // When using the 'MySQL' communication stack, the account must already
+  // exist in the joining member since authentication is based on MySQL
+  // credentials so the account must exist in both ends before GR
+  // starts. For those reasons, we must create the account with binlog
+  // disabled before starting GR, otherwise we'd create errant
+  // transaction
+  mysqlshdk::mysql::Suppress_binary_log nobinlog(m_target_instance.get());
+
+  if (m_target_instance->get_sysvar_bool("super_read_only").get_safe()) {
+    m_target_instance->set_sysvar("super_read_only", false);
+  }
+
+  std::string repl_account_host;
+  mysqlshdk::mysql::Auth_options repl_account;
+
+  std::tie(repl_account, repl_account_host) =
+      m_cluster->create_replication_user(
+          m_target_instance.get(), true,
+          m_gr_opts.recovery_credentials.get_safe(), false);
+
+  // Change GR's recovery replication credentials in all possible
+  // donors so they are able to connect to the joining member. GR will pick a
+  // suitable donor (that we cannot determine) and it needs to be able to
+  // connect and authenticate to the joining member.
+  // NOTE: Instances in RECOVERING must be skipped since won't be used as donor
+  // and the change source command would fail anyway
+  change_recovery_credentials_all_members(repl_account, repl_account_host);
+
+  DBUG_EXECUTE_IF("fail_recovery_mysql_stack", {
+    // Revoke the REPLICATION_SLAVE to make the distributed recovery fail
+    auto primary = m_cluster->get_primary_master();
+    primary->execute("REVOKE REPLICATION SLAVE on *.* from " +
+                     repl_account.user);
+    m_target_instance->execute("REVOKE REPLICATION SLAVE on *.* from " +
+                               repl_account.user);
+  });
+}
+
 /**
  * Clean (drop) the replication user, in case the operation fails.
  */
@@ -816,8 +1074,6 @@ void Cluster_join::clean_replication_user() {
 }
 
 void Cluster_join::log_used_gr_options() {
-  auto console = mysqlsh::current_console();
-
   if (!m_gr_opts.local_address.is_null() && !m_gr_opts.local_address->empty()) {
     log_info("Using Group Replication local address: %s",
              m_gr_opts.local_address->c_str());
@@ -961,6 +1217,18 @@ void Cluster_join::wait_recovery(const std::string &join_begin_time,
   }
 }
 
+void Cluster_join::validate_add_rejoin_options() const {
+  // ipAllowList cannot be used by addInstance/rejoinInstance when the
+  // communication stack in use by the Cluster is 'MySQL'
+  if (m_cluster->get_communication_stack() == kCommunicationStackMySQL &&
+      !m_gr_opts.ip_allowlist.is_null()) {
+    throw shcore::Exception::argument_error(shcore::str_format(
+        "Cannot use '%s' when the Cluster's communication stack is "
+        "'%s'",
+        m_gr_opts.ip_allowlist_option_name.c_str(), kCommunicationStackMySQL));
+  }
+}
+
 void Cluster_join::join(Recovery_progress_style progress_style) {
   auto console = mysqlsh::current_console();
 
@@ -1000,6 +1268,7 @@ void Cluster_join::join(Recovery_progress_style progress_style) {
       mysqlshdk::mysql::is_clone_available(*m_target_instance);
 
   int64_t restore_clone_threshold = 0;
+  bool restore_recovery_accounts = false;
 
   if (clone_supported) {
     // Clone must e uninstalled only when disableClone is enabled on the
@@ -1039,6 +1308,50 @@ void Cluster_join::join(Recovery_progress_style progress_style) {
     configure_cluster_set_member();
   }
 
+  const auto post_failure_actions = [this](bool owns_rpl_user,
+                                           bool drop_rpl_user,
+                                           int64_t restore_clone_thrsh,
+                                           bool restore_rec_accounts) {
+    assert(restore_clone_thrsh >= -1);
+
+    if (owns_rpl_user && drop_rpl_user) {
+      clean_replication_user();
+    }
+
+    if (restore_rec_accounts) {
+      restore_recovery_account_all_members();
+    }
+
+    // Check if group_replication_clone_threshold must be restored.
+    // This would only be needed if the clone failed and the server didn't
+    // restart.
+    if (restore_clone_thrsh != 0) {
+      try {
+        // TODO(miguel): 'start group_replication' returns before reading the
+        // threshold value so we can have a race condition. We should wait
+        // until the instance is 'RECOVERING'
+        log_debug(
+            "Restoring value of group_replication_clone_threshold to: %s.",
+            std::to_string(restore_clone_thrsh).c_str());
+
+        // If -1 we must restore it's default, otherwise we restore the
+        // initial value
+        if (restore_clone_thrsh == -1) {
+          m_target_instance->set_sysvar_default(
+              "group_replication_clone_threshold");
+        } else {
+          m_target_instance->set_sysvar("group_replication_clone_threshold",
+                                        restore_clone_thrsh);
+        }
+      } catch (const shcore::Error &e) {
+        log_info(
+            "Could not restore value of group_replication_clone_threshold: %s. "
+            "Not a fatal error.",
+            e.what());
+      }
+    }
+  };
+
   try {
     // we need a point in time as close as possible, but still earlier than
     // when recovery starts to monitor the recovery phase. The timestamp
@@ -1060,6 +1373,27 @@ void Cluster_join::join(Recovery_progress_style progress_style) {
             m_primary_instance->get_connection_options().get_user().c_str(),
             m_primary_instance->descr().c_str());
 
+        // If using 'MySQL' communication stack, the account must already
+        // exist in the joining member since authentication is based on MySQL
+        // credentials so the account must exist in both ends before GR
+        // starts. For those reasons, we must create the account with binlog
+        // disabled before starting GR, otherwise we'd create errant
+        // transaction
+        if (m_comm_stack == kCommunicationStackMySQL) {
+          create_local_replication_user();
+
+          // At this point, all Cluster members got the recovery credentials
+          // changed to be able to use the account created for the joining
+          // member so in case of failure, we must restore all
+          restore_recovery_accounts = true;
+
+          DBUG_EXECUTE_IF("fail_add_instance_mysql_stack", {
+            // Throw an exception to simulate a failure at
+            // this point in addInstance()
+            throw std::logic_error("debug");
+          });
+        }
+
         // Join the instance to the Group Replication group.
         mysqlsh::dba::join_cluster(*m_target_instance, *m_primary_instance,
                                    m_gr_opts, cluster_member_count, cfg.get());
@@ -1099,7 +1433,12 @@ void Cluster_join::join(Recovery_progress_style progress_style) {
 
       // Store the username in the Metadata instances table
       if (owns_repl_user) {
-        store_cloned_replication_account();
+        if (m_comm_stack == kCommunicationStackMySQL &&
+            progress_style == Recovery_progress_style::NOWAIT) {
+          store_local_replication_account();
+        } else {
+          store_cloned_replication_account();
+        }
       }
     }
 
@@ -1115,6 +1454,49 @@ void Cluster_join::join(Recovery_progress_style progress_style) {
       restore_group_replication_account();
     }
 
+    // Reconfigure the recovery account in every single active member of the
+    // cluster to use its own GR recovery replication credentials and
+    // not the one that was created for the joining instance.
+    //
+    // A joining member needs to be able to connect to itself and to all cluster
+    // members, as well as all cluster members need to be able to connect to the
+    // joining member.
+    //
+    // 1) Group is bootstrapped on server1.
+    //  create recovery account:  mysql_innodb_cluster_1
+    //  change master to use mysql_innodb_cluster_1
+    //
+    // 2) server2 is added to the group
+    //    create recovery account at server 2 and group:
+    //    mysql_innodb_cluster_2 change master at server 2 to use
+    //    mysql_innodb_cluster_2 change master at server seed (server 1) to
+    //    use mysql_innodb_cluster_2 start GR, join OK change master at seed
+    //    (server1) to use mysql_innodb_cluster_1
+    //
+    // 3) server3 is added to the group
+    //    create recovery account at server 3 and group:
+    //    mysql_innodb_cluster_3 change master at server 3 to use
+    //    mysql_innodb_cluster_3 change master at all online members (server
+    //    1, server 2) to use mysql_innodb_cluster_3 start GR, join OK change
+    //    master at server1 to use mysql_innodb_cluster_1 change master at
+    //    server2 to use mysql_innodb_cluster_2
+    //
+    // 4) server3 is removed from the group
+    //      mysql_innodb_cluster_3 account is dropped on all group servers.
+    //
+    // 5) server1 goes offline and restarts
+    //  recovery kicks-in, using mysql_innodb_cluster_1 -> OK
+    //
+    // NOTE: if waitRecovery is zero we cannot do it because
+    // restore_recovery_account_all_members() will happen before clone has
+    // finished so the credentials for the replication channel (that are cloned
+    // to the instance joining) won't match since they were already reset in the
+    // Cluster by restore_recovery_account_all_members().
+    if (m_comm_stack == kCommunicationStackMySQL &&
+        progress_style != Recovery_progress_style::NOWAIT) {
+      restore_recovery_account_all_members();
+    }
+
     // Only commit transaction once everything is done, so that things don't
     // look all fine if something fails in the middle
     trx.commit();
@@ -1124,37 +1506,29 @@ void Cluster_join::join(Recovery_progress_style progress_style) {
     console->print_info("The instance '" + m_target_instance->descr() +
                         "' was successfully added to the cluster.");
     console->print_info();
-  } catch (...) {
-    if (owns_repl_user) clean_replication_user();
-
-    try {
-      // Check if group_replication_clone_threshold must be restored.
-      // This would only be needed if the clone failed and the server didn't
-      // restart.
-      if (restore_clone_threshold != 0) {
-        // TODO(miguel): 'start group_replication' returns before reading the
-        // threshold value so we can have a race condition. We should wait
-        // until the instance is 'RECOVERING'
-        log_debug(
-            "Restoring value of group_replication_clone_threshold to: %s.",
-            std::to_string(restore_clone_threshold).c_str());
-
-        // If -1 we must restore it's default, otherwise we restore the
-        // initial value
-        if (restore_clone_threshold == -1) {
-          m_target_instance->set_sysvar_default(
-              "group_replication_clone_threshold");
-        } else {
-          m_target_instance->set_sysvar("group_replication_clone_threshold",
-                                        restore_clone_threshold);
-        }
-      }
-    } catch (const shcore::Error &e) {
-      log_info(
-          "Could not restore value of group_replication_clone_threshold: %s. "
-          "Not a fatal error.",
-          e.what());
+  } catch (const shcore::Exception &error) {
+    bool drop_replication_user = false;
+    // Do not remove the replication account if there was a timeout waiting for
+    // clone to complete, otherwise, whenever restarting the instance to
+    // complete the process it will fail since the account doesn't exist
+    // anymore. This is more impacting when using 'MySQL' communication stack
+    if (error.code() != SHERR_DBA_SERVER_RESTART_TIMEOUT) {
+      drop_replication_user = true;
+    } else {
+      // Do not restore the recovery accounts if the exception was due to a
+      // timeout waiting for clone to complete, otherwise, restarting the
+      // instance to complete the process fails
+      restore_recovery_accounts = false;
     }
+
+    post_failure_actions(owns_repl_user, drop_replication_user,
+                         restore_clone_threshold, restore_recovery_accounts);
+
+    throw;
+  } catch (...) {
+    post_failure_actions(owns_repl_user, false, restore_clone_threshold,
+                         restore_recovery_accounts);
+
     throw;
   }
 }
@@ -1203,9 +1577,53 @@ void Cluster_join::rejoin() {
   mysqlshdk::utils::nullable<uint64_t> cluster_count =
       m_cluster->get_metadata_storage()->get_cluster_size(m_cluster->get_id()) -
       1;
+
+  // we need a point in time as close as possible, but still earlier than
+  // when recovery starts to monitor the recovery phase. The timestamp
+  // resolution is timestamp(3) irrespective of platform
+  std::string join_begin_time =
+      m_target_instance->queryf_one_string(0, "", "SELECT NOW(3)");
+
+  // If using 'MySQL' communication stack, the account must already
+  // exist in the rejoining member since authentication is based on MySQL
+  // credentials so the account must exist in both ends before GR
+  // starts. However, we cannot assure the account credentials haven't changed
+  // in the cluster resulting in a mismatch. That'd be the case if
+  // cluster.resetRecoveryAccounts() was used while the instance was offline.
+  // For that reason, we simply re-create the account to ensure it will rejoin
+  // the cluster.
+  if (m_comm_stack == kCommunicationStackMySQL) {
+    console->print_info("Re-creating recovery account...");
+    // Re-create the account in the cluster
+    create_replication_user();
+
+    // Re-create the account in the instance but with binlog disabled before
+    // starting GR, otherwise we'd create errant transaction.
+    create_local_replication_user();
+
+    // Set the allowlist to 'AUTOMATIC' to ensure no older values are used
+    m_gr_opts.ip_allowlist = "AUTOMATIC";
+  }
+
   mysqlsh::dba::join_cluster(*m_target_instance, *m_primary_instance, m_gr_opts,
                              cluster_count, cfg.get());
 
+  if (m_comm_stack == kCommunicationStackMySQL) {
+    // We cannot call restore_recovery_account_all_members() without knowing
+    // whether recovery has started already, otherwise, the credentials for
+    // the replication channel won't match since they were already reset in the
+    // Cluster. So we must wait for recovery to start before restoring the
+    // recovery accounts.
+    //
+    // TODO(anyone): whenever clone support is added to rejoinInstance() the
+    // call to wait_recovery_start can be removed since wait_recovery() will be
+    // used, regardless of the communication stack.
+    wait_recovery_start(m_target_instance->get_connection_options(),
+                        join_begin_time, k_recovery_start_timeout);
+
+    restore_recovery_account_all_members();
+  }
+
   // Update group_seeds in other members
   update_group_peers(0, m_target_instance->get_canonical_address(), true);
 
@@ -1223,6 +1641,110 @@ void Cluster_join::reboot() {
   // Common informative logging
   log_used_gr_options();
 
+  // If the Cluster is using the 'MySQL' communication stack, we cannot
+  // guarantee that:
+  //
+  //   - The recovery account exists and is configured at every Cluster member
+  //   - The recovery credentials didn't change (for example after a
+  //   .resetRecoveryAccountsPassword())
+  //   - The recovery credentials have the required Grants
+  //
+  // For those reasons, we must simply re-create the recovery account
+  if (m_gr_opts.communication_stack.get_safe() == kCommunicationStackMySQL) {
+    // If it's a Replica cluster, we must disable the binary logging and
+    // ensure the are created later
+    if (m_cluster->is_cluster_set_member() &&
+        !m_cluster->is_primary_cluster()) {
+      m_target_instance->execute("SET session sql_log_bin = 0");
+    }
+
+    // Disable SRO if enabled
+    if (m_target_instance->get_sysvar_bool("super_read_only").get_safe()) {
+      m_target_instance->set_sysvar("super_read_only", false);
+    }
+
+    // Get the recovery account stored in the Metadata
+    std::string recovery_user;
+    std::vector<std::string> recovery_user_hosts;
+    try {
+      std::tie(recovery_user, recovery_user_hosts, std::ignore) =
+          m_cluster->get_replication_user(*m_target_instance);
+    } catch (const shcore::Exception &re) {
+      if (re.is_runtime()) {
+        mysqlsh::current_console()->print_error(
+            "Unsupported recovery account has been found for "
+            "instance " +
+            m_target_instance->descr() +
+            ". Operations such as "
+            "<Cluster>.<<<resetRecoveryAccountsPassword>>>() and "
+            "<Cluster>.<<<addInstance>>>() may fail. Please remove and "
+            "add the instance back to the Cluster to ensure a "
+            "supported recovery account is used.");
+      }
+      throw;
+    }
+
+    mysqlshdk::mysql::Auth_options repl_account;
+    repl_account.user = recovery_user;
+
+    // Check if the replication user already exists to delete it
+    // before creating it again
+    for (const auto &hostname : recovery_user_hosts) {
+      if (!m_target_instance->user_exists(repl_account.user, hostname))
+        continue;
+
+      current_console()->print_note(shcore::str_format(
+          "User '%s'@'%s' already existed at instance '%s'. It will be "
+          "deleted and created again with a new password.",
+          repl_account.user.c_str(), hostname.c_str(),
+          m_target_instance->descr().c_str()));
+
+      m_target_instance->drop_user(repl_account.user, hostname);
+    }
+
+    // Get the replicationAllowedHost value set for the Cluster
+    std::string repl_account_host = "%";
+
+    if (shcore::Value allowed_host;
+        m_cluster->get_metadata_storage()->query_cluster_set_attribute(
+            m_cluster->get_id(), k_cluster_attribute_replication_allowed_host,
+            &allowed_host) &&
+        allowed_host.type == shcore::String &&
+        !allowed_host.as_string().empty()) {
+      repl_account_host = allowed_host.as_string();
+    }
+
+    // Create a new recovery account
+    repl_account = mysqlshdk::gr::create_recovery_user(
+        repl_account.user, *m_target_instance, {repl_account_host}, {}, true,
+        false, true);
+
+    // Change GR's recovery replication credentials in all possible
+    // donors so whenever GR picks a suitable donor it will be able to
+    // connect and authenticate at the target
+    // NOTE: Instances in RECOVERING must be skipped since won't be used
+    // as donor and the change source command would fail anyway
+    mysqlshdk::mysql::change_replication_credentials(
+        *m_target_instance, repl_account.user, repl_account.password.get_safe(),
+        mysqlshdk::gr::k_gr_recovery_channel);
+
+    if (m_cluster->is_cluster_set_member() &&
+        !m_cluster->is_primary_cluster()) {
+      m_target_instance->execute("SET session sql_log_bin = 1");
+    }
+
+    // Insert the recovery account on the Metadata Schema.
+    m_cluster->get_metadata_storage()->update_instance_repl_account(
+        m_target_instance->get_uuid(), Cluster_type::GROUP_REPLICATION,
+        repl_account.user, repl_account_host);
+
+    // Set the allowlist to 'AUTOMATIC' to ensure no older values are used
+    // since reboot will re-use the values persisted in the instance NOTE:
+    // AUTOMATIC because there's no other allowed value when using the 'MySQL'
+    // communication stack
+    m_gr_opts.ip_allowlist = "AUTOMATIC";
+  }
+
   // Make sure the GR plugin is installed (only installed if needed).
   // NOTE: An error is issued if it fails to be installed (e.g., DISABLED).
   //       Disable read-only temporarily to install the plugin if needed.
@@ -1240,9 +1762,8 @@ void Cluster_join::reboot() {
            m_target_instance->get_connection_options().get_user().c_str());
 
   // Determine the topology mode to use.
-  mysqlshdk::utils::nullable<bool> multi_primary =
-      m_cluster->get_cluster_topology_type() ==
-      mysqlshdk::gr::Topology_mode::MULTI_PRIMARY;
+  auto multi_primary = m_cluster->get_cluster_topology_type() ==
+                       mysqlshdk::gr::Topology_mode::MULTI_PRIMARY;
 
   // Start the cluster to bootstrap Group Replication.
   mysqlsh::dba::start_cluster(*m_target_instance, m_gr_opts, multi_primary,
@@ -1250,8 +1771,8 @@ void Cluster_join::reboot() {
 
   // Wait for the seed instance to become ONLINE in the Group.
   // Especially relevant on Replica Clusters to ensure the seed instance is
-  // already ONLINE when other members try to rejoin the Cluster, otherwise, the
-  // rejoining members will fail to rejoin because the managed replication
+  // already ONLINE when other members try to rejoin the Cluster, otherwise,
+  // the rejoining members will fail to rejoin because the managed replication
   // channel may be started with auto-failover while the members haven't
   // obtained those channel configurations yet.
   uint32_t timeout = 5 * 60 * 1000;  // 5 minutes
@@ -1261,6 +1782,16 @@ void Cluster_join::reboot() {
 
   mysqlshdk::gr::wait_member_online(*m_target_instance, timeout);
 
+  // Update the instances Metadata to ensure 'grLocal' reflects the new value
+  // for local_address
+  // Do it only when communicationStack is used and it's not a replica cluster
+  // to not introduce errant transactions
+  if (!m_gr_opts.communication_stack.is_null() &&
+      (!m_cluster->is_cluster_set_member() ||
+       m_cluster->is_primary_cluster())) {
+    m_cluster->update_metadata_for_instance(*m_target_instance);
+  }
+
   log_debug("Instance add finished");
 }
 
