@@ -193,7 +193,10 @@ shcore::Dictionary_t Status::check_group_status(
 
       desc_status = "Cluster was invalidated by the ClusterSet it belongs to.";
     } else if (number_of_failures_tolerated == 0) {
-      rs_status = Cluster_status::OK_NO_TOLERANCE;
+      if (missing_from_group > 0 || total_in_group != quorum_size)
+        rs_status = Cluster_status::OK_NO_TOLERANCE_PARTIAL;
+      else
+        rs_status = Cluster_status::OK_NO_TOLERANCE;
 
       desc_status = "Cluster is NOT tolerant to any failures.";
     } else {
@@ -398,6 +401,54 @@ shcore::Value Status::applier_status(
   return shcore::Value(dict);
 }
 
+static constexpr const char *k_calculate_lag_query = R"*(
+SELECT
+    IF( /* IF  replication connection or sql thread is not running, we return
+           'null', replication isn't working properly
+        */
+        applier_coordinator_status.SERVICE_STATE = 'OFF'
+        OR conn_status.SERVICE_STATE = 'OFF',
+        'null',
+        IF(
+            /* When the last queued gtid and last applied gtid is the same,
+               then the applier applied everything in the queue
+               In addition when the applying transaction is 0 (e.g. due to
+               replication restart) we also have nothing to execute
+            */
+            GTID_SUBTRACT(conn_status.LAST_QUEUED_TRANSACTION,
+            applier_status.LAST_APPLIED_TRANSACTION) = ''
+            OR UNIX_TIMESTAMP(applier_status.APPLYING_TRANSACTION_IMMEDIATE_COMMIT_TIMESTAMP) = 0,
+            'applier_queue_applied',
+            /* Replication lag is the diff between now and the time it was
+               committed by its source
+            */
+            TIMEDIFF(
+                NOW(6),
+                applier_status.APPLYING_TRANSACTION_IMMEDIATE_COMMIT_TIMESTAMP
+            )
+        )
+    ) AS cluster_member_lag
+FROM
+    performance_schema.replication_connection_status AS conn_status
+    JOIN performance_schema.replication_applier_status_by_worker AS applier_status ON applier_status.channel_name = conn_status.channel_name
+    JOIN performance_schema.replication_applier_status_by_coordinator AS applier_coordinator_status ON applier_coordinator_status.channel_name = conn_status.channel_name
+WHERE
+    conn_status.channel_name = 'group_replication_applier'
+ORDER BY
+    /* As we have a row returned per worker thread, we need to obtain the
+       worker that is executing the oldest transaction to find replication lag.
+       Because workers can be idle, we have to put a lower priority on them,
+       hence the ordering by 0-EXECUTING, 1-IDLE first
+    */
+    IF(GTID_SUBTRACT(conn_status.LAST_QUEUED_TRANSACTION,
+      applier_status.LAST_APPLIED_TRANSACTION) = ''
+            OR UNIX_TIMESTAMP(applier_status.APPLYING_TRANSACTION_IMMEDIATE_COMMIT_TIMESTAMP) = 0,
+            '1-IDLE', '0-EXECUTING') ASC,
+    applier_status.APPLYING_TRANSACTION_IMMEDIATE_COMMIT_TIMESTAMP ASC
+LIMIT
+    1;
+)*";
+
 /**
  * Similar to collect_local_status(), but only includes basic/important
  * stats that should be displayed in the default output.
@@ -447,35 +498,15 @@ void Status::collect_basic_local_status(shcore::Dictionary_t dict,
         }
       }
     } else {
-      sql = "SELECT ";
-      sql +=
-          "IF(c.LAST_QUEUED_TRANSACTION=''"
-          " OR c.LAST_QUEUED_TRANSACTION=a.LAST_APPLIED_TRANSACTION"
-          " OR a.LAST_APPLIED_TRANSACTION_END_APPLY_TIMESTAMP <"
-          "  a.LAST_APPLIED_TRANSACTION_ORIGINAL_COMMIT_TIMESTAMP,"
-          "NULL, " TSDIFF("LAST_APPLIED_TRANSACTION",
-                          "ORIGINAL_COMMIT_TIMESTAMP",
-                          "END_APPLY_TIMESTAMP") ")";
-      sql += " AS LAST_ORIGINAL_COMMIT_TO_END_APPLY_TIME";
-      sql +=
-          " FROM performance_schema.replication_applier_status_by_worker a"
-          " JOIN performance_schema.replication_connection_status c"
-          "   ON a.channel_name = c.channel_name"
-          " WHERE a.channel_name = 'group_replication_applier'";
-
-      // this can return multiple rows per channel for
-      // multi-threaded applier, otherwise just one. If MT, we also
-      // get stuff in the coordinator table
-      auto result = instance.query(sql);
+      auto result = instance.query(k_calculate_lag_query);
       auto row = result->fetch_one_named();
       if (row) {
-        std::string lag =
-            row.get_string("LAST_ORIGINAL_COMMIT_TO_END_APPLY_TIME", "");
+        std::string lag = row.get_string("cluster_member_lag", "");
 
-        if (!lag.empty() && lag != "00:00:00.000000") {
-          (*dict)["replicationLag"] = shcore::Value(lag);
-        } else {
+        if (lag == "null" || lag.empty()) {
           (*dict)["replicationLag"] = shcore::Value::Null();
+        } else {
+          (*dict)["replicationLag"] = shcore::Value(lag);
         }
       }
     }
@@ -640,6 +671,7 @@ void Status::feed_metadata_info(shcore::Dictionary_t dict,
 
 void Status::feed_member_info(
     shcore::Dictionary_t dict, const mysqlshdk::gr::Member &member,
+    const mysqlshdk::utils::nullable<bool> &offline_mode,
     const mysqlshdk::utils::nullable<bool> &super_read_only,
     const std::vector<std::string> &fence_sysvars,
     mysqlshdk::gr::Member_state self_state, bool is_auto_rejoin_running) {
@@ -671,14 +703,19 @@ void Status::feed_member_info(
   (*dict)["status"] = shcore::Value(mysqlshdk::gr::to_string(member.state));
 
   // Set the instance mode (read-only or read-write).
-  if (super_read_only.is_null()) {
-    // super_read_only is null if it could not be obtained from the instance.
+  if (offline_mode.is_null() || super_read_only.is_null()) {
+    // offline_mode or super_read_only is null if it could not be obtained from
+    // the instance.
     (*dict)["mode"] = shcore::Value("n/a");
   } else {
-    // Set mode to read-only if there is no quorum otherwise according to the
-    // instance super_read_only value.
-    (*dict)["mode"] =
-        shcore::Value((m_no_quorum || *super_read_only) ? "R/O" : "R/W");
+    // We deal with offline mode the same as n/a and set mode to read-only if
+    // there is no quorum otherwise according to the instance super_read_only
+    // value.
+    if (*offline_mode)
+      (*dict)["mode"] = shcore::Value("n/a");
+    else
+      (*dict)["mode"] =
+          shcore::Value((m_no_quorum || *super_read_only) ? "R/O" : "R/W");
   }
 
   // Display autoRejoinRunning attribute by default for each member, but only
@@ -894,7 +931,8 @@ void check_host_metadata(shcore::Array_t issues, Instance *instance,
                          const Instance_metadata_info &instance_md) {
   auto address = instance->get_canonical_address();
 
-  if (instance_md.md.endpoint != address) {
+  if (!mysqlshdk::utils::are_endpoints_equal(instance_md.md.endpoint,
+                                             address)) {
     issues->push_back(
         shcore::Value("ERROR: Metadata for this instance does not match "
                       "hostname reported by instance (metadata=" +
@@ -1014,13 +1052,25 @@ void check_comm_protocol_upgrade_possible(
     // get the lowest protocol version supported by the group members
     auto highest_possible_version = all_protocol_versions.front();
     if (highest_possible_version > protocol_version) {
-      issues->emplace_back(shcore::Value(
-          "Group communication protocol in use is version " +
-          protocol_version.get_full() + " but it is possible to upgrade to " +
-          highest_possible_version.get_full() +
-          ". Message fragmentation for large transactions can only be "
-          "enabled after upgrade. Use "
-          "Cluster.rescan({upgradeCommProtocol:true}) to upgrade."));
+      std::string str = "Group communication protocol in use is version " +
+                        protocol_version.get_full() +
+                        " but it is possible to upgrade to " +
+                        highest_possible_version.get_full() + ".";
+
+      if (protocol_version < mysqlshdk::utils::Version(8, 0, 16)) {
+        str += " Message fragmentation for large transactions";
+        if (highest_possible_version == mysqlshdk::utils::Version(8, 0, 27)) {
+          str += " and Single Consensus Leader";
+        }
+
+        str += " can only be enabled after upgrade.";
+      } else {
+        str += " Single Consensus Leader can only be enabled after upgrade.";
+      }
+
+      str += " Use Cluster.rescan({upgradeCommProtocol:true}) to upgrade.";
+
+      issues->emplace_back(shcore::Value(str));
     }
   }
 }
@@ -1161,24 +1211,27 @@ shcore::Dictionary_t Status::get_topology(
     if (!found) {
       // if instance in MD was not found by uuid, then search by address
       for (const auto &i : m_instances) {
-        if (i.address == m.host + ":" + std::to_string(m.port)) {
-          log_debug(
-              "Instance with address=%s is in group, but UUID doesn't match "
-              "group=%s MD=%s",
-              i.endpoint.c_str(), m.uuid.c_str(), i.uuid.c_str());
+        if (!mysqlshdk::utils::are_endpoints_equal(
+                i.address,
+                mysqlshdk::utils::make_host_and_port(m.host, m.port)))
+          continue;
 
-          Instance_metadata_info mdi;
-          mdi.md = i;
-          mdi.actual_server_uuid = m.uuid;
-          instances.emplace_back(std::move(mdi));
-          found = true;
-          break;
-        }
+        log_debug(
+            "Instance with address=%s is in group, but UUID doesn't match "
+            "group=%s MD=%s",
+            i.endpoint.c_str(), m.uuid.c_str(), i.uuid.c_str());
+
+        Instance_metadata_info mdi;
+        mdi.md = i;
+        mdi.actual_server_uuid = m.uuid;
+        instances.emplace_back(std::move(mdi));
+        found = true;
+        break;
       }
     }
     if (!found) {
       Instance_metadata_info mdi;
-      mdi.md.address = m.host + ":" + std::to_string(m.port);
+      mdi.md.address = mysqlshdk::utils::make_host_and_port(m.host, m.port);
       mdi.md.label = mdi.md.address;
       mdi.md.uuid = m.uuid;
       mdi.md.endpoint = mdi.md.address;
@@ -1207,7 +1260,9 @@ shcore::Dictionary_t Status::get_topology(
     bool found = false;
     for (const auto &m : member_info) {
       if (m.uuid == i.uuid ||
-          i.endpoint == m.host + ":" + std::to_string(m.port)) {
+          mysqlshdk::utils::are_endpoints_equal(
+              i.endpoint,
+              mysqlshdk::utils::make_host_and_port(m.host, m.port))) {
         found = true;
         break;
       }
@@ -1216,7 +1271,7 @@ shcore::Dictionary_t Status::get_topology(
       log_debug("Instance with uuid=%s address=%s is in MD but not in group",
                 i.uuid.c_str(), i.endpoint.c_str());
 
-      auto &instance(m_member_sessions[i.endpoint]);
+      auto &instance = m_member_sessions[i.endpoint];
 
       Instance_metadata_info mdi;
       mdi.md = i;
@@ -1244,9 +1299,10 @@ shcore::Dictionary_t Status::get_topology(
     mysqlshdk::gr::Member_state self_state =
         mysqlshdk::gr::Member_state::MISSING;
 
-    auto &instance(m_member_sessions[inst.md.endpoint]);
+    auto &instance = m_member_sessions[inst.md.endpoint];
 
     mysqlshdk::utils::nullable<bool> super_read_only;
+    mysqlshdk::utils::nullable<bool> offline_mode;
     std::vector<std::string> fence_sysvars;
     bool auto_rejoin = false;
 
@@ -1262,6 +1318,9 @@ shcore::Dictionary_t Status::get_topology(
       // Get super_read_only value of each instance to set the mode accurately.
       super_read_only = instance->get_sysvar_bool("super_read_only");
 
+      // Get offline_mode value of each instance to set the mode accurately.
+      offline_mode = instance->get_sysvar_bool("offline_mode");
+
       // Check if auto-rejoin is running.
       auto_rejoin = mysqlshdk::gr::is_running_gr_auto_rejoin(*instance);
 
@@ -1358,13 +1417,17 @@ shcore::Dictionary_t Status::get_topology(
           shcore::Value(m_member_connect_errors[inst.md.endpoint]);
     }
     feed_metadata_info(member, inst.md);
-    feed_member_info(member, minfo, super_read_only, fence_sysvars, self_state,
-                     auto_rejoin);
+    feed_member_info(member, minfo, offline_mode, super_read_only,
+                     fence_sysvars, self_state, auto_rejoin);
 
     shcore::Array_t issues = instance_diagnostics(
         instance.get(), &m_cluster, inst, recovery_channel, applier_channel,
         super_read_only, minfo, self_state, parallel_applier_options);
 
+    if (offline_mode.get_safe(false))
+      issues->push_back(
+          shcore::Value("WARNING: Instance has offline_mode enabled."));
+
     auto ret_val = validate_instance_recovery_user(
         instance, endpoints, inst.actual_server_uuid, self_state);
 
@@ -1436,14 +1499,31 @@ shcore::Dictionary_t Status::collect_replicaset_status() {
 
   if ((!m_extended.is_null() && *m_extended >= 1)) {
     (*ret)["groupName"] = shcore::Value(m_cluster.get_group_name());
+
     if (group_instance &&
-        group_instance->get_version() >= mysqlshdk::utils::Version(8, 0, 26))
+        group_instance->get_version() >= mysqlshdk::utils::Version(8, 0, 26)) {
       (*ret)["groupViewChangeUuid"] =
           shcore::Value(*group_instance->get_sysvar_string(
               "group_replication_view_change_uuid"));
+    }
+
     (*ret)["GRProtocolVersion"] =
         protocol_version ? shcore::Value(protocol_version.get_full())
                          : shcore::Value::Null();
+
+    // Add the communicationStack
+    //
+    // Always add the value of the communicationStack regardless of the version
+    // in use, because:
+    //
+    //   - Even before the 'MySQL' communication stack was introduced, 'XCOM'
+    //   was the name of the communication stack used by GR
+    //   - It slightly educates users that there's a possibility of having a
+    //   different communication stack.
+    if (group_instance) {
+      (*ret)[kCommunicationStack] =
+          shcore::Value(m_cluster.get_communication_stack());
+    }
   }
 
   auto ssl_mode = group_instance ? *group_instance->get_sysvar_string(
@@ -1475,17 +1555,16 @@ shcore::Dictionary_t Status::collect_replicaset_status() {
         // In single primary mode we need to add the "primary" field
         (*ret)["primary"] = shcore::Value("?");
         for (const auto &member : member_info) {
-          if (member.role == mysqlshdk::gr::Member_role::PRIMARY) {
-            const Instance_metadata *primary = instance_with_uuid(member.uuid);
-            if (primary) {
-              auto s = m_member_sessions.find(primary->endpoint);
-              if (s != m_member_sessions.end()) {
-                primary_instance = s->second;
-              }
-              (*ret)["primary"] = shcore::Value(primary->endpoint);
+          if (member.role != mysqlshdk::gr::Member_role::PRIMARY) continue;
+          const Instance_metadata *primary = instance_with_uuid(member.uuid);
+          if (primary) {
+            if (auto s = m_member_sessions.find(primary->endpoint);
+                s != m_member_sessions.end()) {
+              primary_instance = s->second;
             }
-            break;
+            (*ret)["primary"] = shcore::Value(primary->endpoint);
           }
+          break;
         }
       }
     }
