@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, 2021, Oracle and/or its affiliates.
+ * Copyright (c) 2016, 2022, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -79,7 +79,8 @@ enum Type {
   AsyncReplicaSet = 1 << 5,
   InnoDBClusterSet = 1 << 6,
   InnoDBClusterSetOffline = 1 << 7,
-  Unknown = 1 << 8
+  AsyncReplication = 1 << 8,
+  Unknown = 1 << 9
 };
 }  // namespace TargetType
 
@@ -248,12 +249,15 @@ constexpr const char kOnlyUpgradeRequired[] = "onlyUpgradeRequired";
 constexpr const char kUpdate[] = "update";
 constexpr const char kUpdateTopologyMode[] = "updateTopologyMode";
 constexpr const char kUpgradeCommProtocol[] = "upgradeCommProtocol";
+constexpr const char kUpdateViewChangeUuid[] = "updateViewChangeUuid";
 constexpr const char kAll[] = "all";
 constexpr const char kTimeout[] = "timeout";
 constexpr const char kInvalidateErrorInstances[] = "invalidateErrorInstances";
 constexpr const char kClusterSetReplicationSslMode[] =
     "clusterSetReplicationSslMode";
 constexpr const char kReplicationAllowedHost[] = "replicationAllowedHost";
+constexpr const char kCommunicationStack[] = "communicationStack";
+constexpr const char kSwitchCommunicationStack[] = "switchCommunicationStack";
 
 constexpr const int k_group_replication_members_limit = 9;
 
@@ -327,6 +331,9 @@ const std::map<std::string, Option_availability> k_instance_supported_options{
     {kAutoRejoinTries,
      {kGrAutoRejoinTries, mysqlshdk::utils::Version("8.0.16"), {}}}};
 
+const mysqlshdk::utils::Version k_mysql_communication_stack_initial_version(
+    "8.0.27");
+
 struct Instance_definition {
   int host_id;
   int replicaset_id;
@@ -385,6 +392,19 @@ const std::set<std::string> kClusterSSLModeValues = {
 std::string to_string(Cluster_ssl_mode ssl_mode);
 Cluster_ssl_mode to_cluster_ssl_mode(const std::string &ssl_mode);
 
+constexpr const char *kCommunicationStackMySQL = "MYSQL";
+constexpr const char *kCommunicationStackXCom = "XCOM";
+
+const std::set<std::string> kCommunicationStackValidValues = {
+    kCommunicationStackXCom, kCommunicationStackMySQL};
+
+/**
+ * Map of the supported Cluster capabilities
+ */
+const std::map<std::string, std::set<std::string>>
+    k_cluster_supported_capabilities{
+        {kCommunicationStack, kCommunicationStackValidValues}};
+
 /**
  * Check if a setting is supported on the target instance
  *
@@ -527,6 +547,8 @@ void add_config_file_handler(mysqlshdk::config::Config *cfg,
  *
  * @param local_address Nullable string with the input local address value to
  *                      resolve.
+ * @param communication_stack Nullable string with the GR communication stack to
+ * be used
  * @param report_host String with the report host value of the instance (host
  *                    used by GR and the Metadata).
  * @param port integer with port used to connect to the instance.
@@ -538,8 +560,10 @@ void add_config_file_handler(mysqlshdk::config::Config *cfg,
  * if it is already being used.
  */
 std::string resolve_gr_local_address(
-    const mysqlshdk::null_string &local_address, const std::string &report_host,
-    int port, bool check_if_busy, bool quiet = false);
+    const mysqlshdk::null_string &local_address,
+    const mysqlshdk::null_string &communication_stack,
+    const std::string &report_host, int port, bool check_if_busy,
+    bool quiet = false);
 
 struct Instance_gtid_info {
   std::string server;
@@ -643,8 +667,9 @@ void handle_deprecated_option(const std::string &deprecated_name,
  * @param  target_instance The target instance
  * @return                 An TargetType::Type representing the instance type
  */
-TargetType::Type get_instance_type(const MetadataStorage &metadata,
-                                   Instance *target_instance = nullptr);
+TargetType::Type get_instance_type(
+    const MetadataStorage &metadata,
+    const mysqlshdk::mysql::IInstance &target_instance);
 
 /**
  * TODO
