@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, 2021, Oracle and/or its affiliates.
+ * Copyright (c) 2016, 2022, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -48,20 +48,29 @@ Router_metadata unserialize_router(const mysqlshdk::db::Row_ref_by_name &row) {
   router.id = row.get_uint("router_id");
   router.hostname = row.get_string("host_name");
   router.name = row.get_string("router_name");
-  if (!row.is_null("ro_port"))
-    router.ro_port = std::stoi(row.get_string("ro_port"));
-  if (!row.is_null("rw_port"))
-    router.rw_port = std::stoi(row.get_string("rw_port"));
-  if (!row.is_null("ro_x_port"))
-    router.ro_x_port = std::stoi(row.get_string("ro_x_port"));
-  if (!row.is_null("rw_x_port"))
-    router.rw_x_port = std::stoi(row.get_string("rw_x_port"));
+
+  if (!row.is_null("ro_port")) {
+    router.ro_port = row.get_string("ro_port");
+  }
+  if (!row.is_null("rw_port")) {
+    router.rw_port = row.get_string("rw_port");
+  }
+  if (!row.is_null("ro_x_port")) {
+    router.ro_x_port = row.get_string("ro_x_port");
+  }
+  if (!row.is_null("rw_x_port")) {
+    router.rw_x_port = row.get_string("rw_x_port");
+  }
   if (row.has_field("bootstrap_target_type") &&
-      !row.is_null("bootstrap_target_type"))
+      !row.is_null("bootstrap_target_type")) {
     router.bootstrap_target_type = row.get_string("bootstrap_target_type");
-  if (!row.is_null("last_check_in"))
+  }
+  if (!row.is_null("last_check_in")) {
     router.last_checkin = row.get_string("last_check_in");
-  if (!row.is_null("version")) router.version = row.get_string("version");
+  }
+  if (!row.is_null("version")) {
+    router.version = row.get_string("version");
+  }
 
   return router;
 }
@@ -218,12 +227,12 @@ std::string get_all_online_check_query(
 
 constexpr const char *k_base_instance_in_cluster_query =
     "SELECT COUNT(*) as count FROM mysql_innodb_cluster_metadata.instances "
-    "WHERE cluster_id = ? AND addresses->'$.mysqlClassic' = ?";
+    "WHERE cluster_id = ? AND LOWER(addresses->>'$.mysqlClassic') = LOWER(?)";
 
 constexpr const char *k_base_instance_in_cluster_query_1_0_1 =
     "SELECT COUNT(*) as count FROM mysql_innodb_cluster_metadata.instances, "
     "mysql_innodb_cluster_metadata.replicasets "
-    "WHERE cluster_id = ? AND addresses->'$.mysqlClassic' = ?";
+    "WHERE cluster_id = ? AND LOWER(addresses->>'$.mysqlClassic') = LOWER(?)";
 
 std::string get_instance_in_cluster_query(
     const mysqlshdk::utils::Version &md_version) {
@@ -587,6 +596,49 @@ void MetadataStorage::update_cluster_attribute(const Cluster_id &cluster_id,
   }
 }
 
+bool MetadataStorage::query_cluster_capability(const Cluster_id &cluster_id,
+                                               const std::string &capability,
+                                               shcore::Value *out_value) const {
+  std::string attribute =
+      std::string(k_cluster_capabilities) + "." + capability;
+
+  return query_cluster_attribute(cluster_id, attribute, out_value);
+}
+
+void MetadataStorage::update_cluster_capability(
+    const Cluster_id &cluster_id, const std::string &capability,
+    const std::string &value, const std::set<std::string> &allowed_operations) {
+  shcore::Dictionary_t cap = shcore::make_dict();
+
+  if (!value.empty()) {
+    shcore::Dictionary_t value_and_allow = shcore::make_dict();
+    shcore::Array_t allowed_ops = shcore::make_array();
+
+    value_and_allow->set("value", shcore::Value(value));
+
+    for (const auto &op : allowed_operations) {
+      allowed_ops->push_back(shcore::Value(op));
+    }
+
+    value_and_allow->set("allow", shcore::Value(allowed_ops));
+
+    cap->set(capability, shcore::Value(value_and_allow));
+  } else {
+    cap->set(capability, shcore::Value(nullptr));
+  }
+
+  shcore::sqlstring query(
+      "UPDATE mysql_innodb_cluster_metadata.clusters"
+      " SET attributes = JSON_MERGE_PATCH(attributes, CAST('{\"" +
+          std::string(k_cluster_capabilities) + "\": " +
+          shcore::Value(cap).repr() + "}' as JSON)) WHERE cluster_id = ?",
+      0);
+
+  query << cluster_id;
+  query.done();
+  execute_sql(query);
+}
+
 void MetadataStorage::update_cluster_set_attribute(
     const Cluster_set_id &clusterset_id, const std::string &attribute,
     const shcore::Value &value) {
@@ -806,20 +858,32 @@ void MetadataStorage::update_instance(const Instance_metadata &instance) {
   std::string attributes;
   attributes = shcore::sqlstring("'server_id', ?", 0) << instance.server_id;
 
+  bool lookup_by_address = instance.id == 0 || instance.cluster_id.empty();
+
   shcore::sqlstring query;
   query = shcore::sqlstring(
       "UPDATE mysql_innodb_cluster_metadata.instances "
-      "SET cluster_id = ?, address = ?, mysql_server_uuid = ?, addresses = "
-      "json_merge_patch(addresses, json_object(" +
-          addresses +
+      "SET cluster_id = ?, address = ?, mysql_server_uuid = ?, " +
+          std::string(instance.label.empty() ? "" : "instance_name = ?, ") +
+          "addresses = json_merge_patch(addresses, json_object(" + addresses +
           ")), attributes = json_merge_patch(attributes, json_object(" +
-          attributes + ")) WHERE address = ?",
+          attributes + ")) WHERE " +
+          (lookup_by_address ? "address = ?"
+                             : "cluster_id = ? AND instance_id = ?"),
       0);
 
   query << instance.cluster_id;
   query << instance.address;
   query << instance.uuid;
-  query << instance.address;
+  if (!instance.label.empty()) {
+    query << instance.label;
+  }
+  if (lookup_by_address) {
+    query << instance.address;
+  } else {
+    query << instance.cluster_id;
+    query << instance.id;
+  }
   query.done();
 
   execute_sql(query);
@@ -1103,8 +1167,8 @@ MetadataStorage::get_instances_with_recovery_accounts(
   return ret_val;
 }
 
-bool MetadataStorage::is_recovery_account_unique(
-    const std::string &recovery_account_user, bool clusterset_account) {
+int MetadataStorage::count_recovery_account_uses(
+    const std::string &recovery_account_user, bool clusterset_account) const {
   shcore::sqlstring query;
 
   if (!recovery_account_user.empty()) {
@@ -1133,22 +1197,18 @@ bool MetadataStorage::is_recovery_account_unique(
       count = row->get_int(0);
     }
 
-    return count == 1;
+    return count;
   }
 
-  return false;
+  return 0;
 }
 
 void MetadataStorage::remove_instance(const std::string &instance_address) {
-  shcore::sqlstring query;
-
   // Remove the instance
-  query = shcore::sqlstring(
-      "DELETE FROM mysql_innodb_cluster_metadata.instances "
-      "WHERE addresses->'$.mysqlClassic' = ?",
-      0);
-  query << instance_address;
-  query.done();
+  auto query = ("DELETE FROM mysql_innodb_cluster_metadata.instances "
+                "WHERE LOWER(addresses->>'$.mysqlClassic') = LOWER(?)"_sql
+                << instance_address)
+                   .str();
 
   execute_sql(query);
 }
@@ -1466,7 +1526,7 @@ Instance_metadata MetadataStorage::get_instance_by_address(
   auto query(get_instance_query(md_version));
 
   if (md_version.get_major() == 1)
-    query += " WHERE i.addresses->>'$.mysqlClassic' = ?";
+    query += " WHERE LOWER(i.addresses->>'$.mysqlClassic') = LOWER(?)";
   else
     query += " WHERE i.address = ?";
 
@@ -2236,7 +2296,7 @@ bool MetadataStorage::remove_router(const std::string &router_def) {
     auto result = execute_sqlf(
         "SELECT router_id FROM mysql_innodb_cluster_metadata.routers r"
         " JOIN mysql_innodb_cluster_metadata.hosts h ON r.host_id = h.host_id"
-        " WHERE r.router_name = ? AND h.host_name = ?",
+        " WHERE r.router_name = ? AND LOWER(h.host_name) = LOWER(?)",
         name, address);
 
     if (auto row = result->fetch_one()) {
@@ -2653,7 +2713,7 @@ bool MetadataStorage::check_metadata(mysqlshdk::utils::Version *out_version,
 }
 
 bool MetadataStorage::check_cluster_set(
-    Instance *target_instance, uint64_t *out_view_id,
+    const mysqlshdk::mysql::IInstance *target_instance, uint64_t *out_view_id,
     std::string *out_cs_domain_name, Cluster_set_id *out_cluster_set_id) const {
   bool ret_val = false;
 
