@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, 2021, Oracle and/or its affiliates.
+ * Copyright (c) 2016, 2022, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -27,6 +27,7 @@
 #include <list>
 #include <map>
 #include <memory>
+#include <set>
 #include <string>
 #include <utility>
 #include <vector>
@@ -112,10 +113,10 @@ struct Router_metadata {
   std::string name;
   uint64_t id;
   std::string hostname;
-  mysqlshdk::utils::nullable<uint64_t> rw_port;
-  mysqlshdk::utils::nullable<uint64_t> ro_port;
-  mysqlshdk::utils::nullable<uint64_t> rw_x_port;
-  mysqlshdk::utils::nullable<uint64_t> ro_x_port;
+  mysqlshdk::utils::nullable<std::string> rw_port;
+  mysqlshdk::utils::nullable<std::string> ro_port;
+  mysqlshdk::utils::nullable<std::string> rw_x_port;
+  mysqlshdk::utils::nullable<std::string> ro_x_port;
   mysqlshdk::utils::nullable<std::string> bootstrap_target_type;
   mysqlshdk::utils::nullable<std::string> last_checkin;
   mysqlshdk::utils::nullable<std::string> version;
@@ -222,6 +223,15 @@ class MetadataStorage : public std::enable_shared_from_this<MetadataStorage> {
                                 const std::string &attribute,
                                 const shcore::Value &value);
 
+  void update_cluster_capability(
+      const Cluster_id &cluster_id, const std::string &capability,
+      const std::string &value,
+      const std::set<std::string> &allowed_operations);
+
+  bool query_cluster_capability(const Cluster_id &cluster_id,
+                                const std::string &capability,
+                                shcore::Value *out_value) const;
+
   void update_cluster_set_attribute(const Cluster_set_id &clusterset_id,
                                     const std::string &attribute,
                                     const shcore::Value &value);
@@ -321,8 +331,8 @@ class MetadataStorage : public std::enable_shared_from_this<MetadataStorage> {
   std::map<std::string, std::string> get_instances_with_recovery_accounts(
       const Cluster_id &cluster_id) const;
 
-  bool is_recovery_account_unique(const std::string &recovery_account_user,
-                                  bool clusterset_account = false);
+  int count_recovery_account_uses(const std::string &recovery_account_user,
+                                  bool clusterset_account = false) const;
 
   virtual bool is_instance_on_cluster(const Cluster_id &cluster_id,
                                       const std::string &address);
@@ -525,10 +535,11 @@ class MetadataStorage : public std::enable_shared_from_this<MetadataStorage> {
   bool check_metadata(mysqlshdk::utils::Version *out_version = nullptr,
                       Cluster_type *out_type = nullptr) const;
 
-  bool check_cluster_set(Instance *target_instance = nullptr,
-                         uint64_t *out_view_id = nullptr,
-                         std::string *out_cs_domain_name = nullptr,
-                         Cluster_set_id *out_cluster_set_id = nullptr) const;
+  bool check_cluster_set(
+      const mysqlshdk::mysql::IInstance *target_instance = nullptr,
+      uint64_t *out_view_id = nullptr,
+      std::string *out_cs_domain_name = nullptr,
+      Cluster_set_id *out_cluster_set_id = nullptr) const;
 
   bool supports_cluster_set() const;
 
