@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019, 2021, Oracle and/or its affiliates.
+ * Copyright (c) 2019, 2022, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -69,7 +69,7 @@ Create_cluster::Create_cluster(const std::shared_ptr<MetadataStorage> &metadata,
       m_cluster_name(cluster_name),
       m_options(options) {}
 
-Create_cluster::~Create_cluster() {}
+Create_cluster::~Create_cluster() = default;
 
 void Create_cluster::validate_create_cluster_options() {
   auto console = mysqlsh::current_console();
@@ -80,58 +80,76 @@ void Create_cluster::validate_create_cluster_options() {
         "The member will only proceed according to its exitStateAction if "
         "auto-rejoin fails (i.e. all retry attempts are exhausted).";
     console->print_warning(warn_msg);
-    console->println();
+    console->print_info();
   }
 
   // Get the instance GR state
   TargetType::Type instance_type = get_gr_instance_type(*m_target_instance);
 
-  if (instance_type == mysqlsh::dba::TargetType::GroupReplication &&
-      !m_options.adopt_from_gr) {
-    if (m_options.interactive()) {
+  if (instance_type == mysqlsh::dba::TargetType::GroupReplication) {
+    if (!m_options.adopt_from_gr && m_options.interactive()) {
       if (console->confirm(
               "You are connected to an instance that belongs to an unmanaged "
-              "replication group.\nDo you want to setup an InnoDB cluster "
+              "replication group.\nDo you want to setup an InnoDB Cluster "
               "based on this replication group?",
               mysqlsh::Prompt_answer::YES) == mysqlsh::Prompt_answer::YES) {
         m_options.adopt_from_gr = true;
       }
     }
-    if (!m_options.adopt_from_gr && !m_retrying)
+
+    if (!m_retrying && !m_options.get_adopt_from_gr())
       throw shcore::Exception(
           "Creating a cluster on an unmanaged replication group requires "
           "adoptFromGR option to be true",
           SHERR_DBA_BADARG_INSTANCE_ALREADY_IN_GR);
   }
 
-  if (m_options.adopt_from_gr &&
+  if (m_options.get_adopt_from_gr() &&
       m_options.gr_options.ssl_mode != Cluster_ssl_mode::NONE) {
     throw shcore::Exception::argument_error(
         "Cannot use memberSslMode option if adoptFromGR is set to true.");
   }
 
-  if (m_options.adopt_from_gr && !m_options.multi_primary.is_null()) {
+  if (m_options.get_adopt_from_gr() && m_options.multi_primary) {
     throw shcore::Exception::argument_error(
         "Cannot use multiPrimary (or multiMaster) option if adoptFromGR is set "
         "to true. Using adoptFromGR mode will adopt the primary mode in use by "
         "the Cluster.");
   }
 
-  if (m_options.adopt_from_gr &&
+  if (m_options.get_adopt_from_gr() &&
       instance_type != TargetType::GroupReplication) {
     throw shcore::Exception::argument_error(
         "The adoptFromGR option is set to true, but there is no replication "
         "group to adopt");
   }
 
-  // Set multi-primary to false by default.
-  if (m_options.multi_primary.is_null()) m_options.multi_primary = false;
+  // Using communicationStack and adoptFromGR and/or ipAllowlist/ipWhitelist at
+  // the same time is forbidden
+  if (m_options.adopt_from_gr &&
+      !m_options.gr_options.communication_stack.is_null()) {
+    throw shcore::Exception::argument_error(
+        shcore::str_format("Cannot use the '%s' option if '%s' is set "
+                           "to true.",
+                           kCommunicationStack, kAdoptFromGR));
+  }
 
-  if (!m_options.adopt_from_gr && *m_options.multi_primary &&
-      !m_options.force.get_safe()) {
+  if (m_options.gr_options.communication_stack.get_safe() ==
+          kCommunicationStackMySQL &&
+      !m_options.gr_options.ip_allowlist.is_null()) {
+    throw shcore::Exception::argument_error(shcore::str_format(
+        "Cannot use '%s' when setting the '%s' option to '%s'",
+        m_options.gr_options.ip_allowlist_option_name.c_str(),
+        kCommunicationStack, kCommunicationStackMySQL));
+  }
+
+  // Set multi-primary to false by default.
+  if (!m_options.multi_primary) m_options.multi_primary = false;
+
+  if (*m_options.multi_primary && !m_options.force.get_safe()) {
     if (m_options.interactive()) {
       console->print_para(
-          "The MySQL InnoDB cluster is going to be setup in advanced "
+          "The MySQL InnoDB Cluster is going to be setup in advanced "
           "Multi-Primary Mode. Before continuing you have to confirm that you "
           "understand the requirements and limitations of Multi-Primary Mode. "
           "For more information see "
@@ -139,15 +157,15 @@ void Create_cluster::validate_create_cluster_options() {
           "group-replication-limitations.html before proceeding.");
 
       console->print_para(
-          "I have read the MySQL InnoDB cluster manual and I understand the "
+          "I have read the MySQL InnoDB Cluster manual and I understand the "
           "requirements and limitations of advanced Multi-Primary Mode.");
 
       if (console->confirm("Confirm", mysqlsh::Prompt_answer::NO) ==
           mysqlsh::Prompt_answer::NO) {
-        console->println();
+        console->print_info();
         throw shcore::cancelled("Cancelled");
       } else {
-        console->println();
+        console->print_info();
         m_options.force = true;
       }
     } else {
@@ -217,19 +235,27 @@ void Create_cluster::resolve_ssl_mode() {
 
 void Create_cluster::prepare() {
   auto console = mysqlsh::current_console();
-  console->println(
-      std::string{"A new InnoDB cluster will be created"} +
-      (m_options.adopt_from_gr ? " based on the existing replication group"
-                               : "") +
-      " on instance '" +
-      m_target_instance->get_connection_options().uri_endpoint() + "'.\n");
+
+  std::string msg = "A new InnoDB Cluster will be created ";
+
+  if (m_options.adopt_from_gr) {
+    msg += "based on the existing replication group ";
+  }
+
+  msg += "on instance '" + m_target_instance->descr();
+  msg += "'.";
+
+  console->print_info(msg);
+  console->print_info();
 
   // Validate the cluster_name
   mysqlsh::dba::validate_cluster_name(m_cluster_name,
                                       Cluster_type::GROUP_REPLICATION);
 
   // Validate values given for GR options.
-  m_options.gr_options.check_option_values(m_target_instance->get_version());
+  m_options.gr_options.check_option_values(
+      m_target_instance->get_version(),
+      m_target_instance->get_canonical_port());
 
   // Validate the Clone options.
   m_options.clone_options.check_option_values(m_target_instance->get_version());
@@ -245,6 +271,34 @@ void Create_cluster::prepare() {
   // Validate create cluster options (combinations).
   validate_create_cluster_options();
 
+  // The default value for communicationStack must be 'mysql' if the target
+  // instance is running 8.0.27+
+  // NOTE: When adoptFromGR is used, we don't set the communication stack since
+  // the one in use by the unmanaged GR group must be kept
+  if (m_options.gr_options.communication_stack.is_null() &&
+      !m_options.adopt_from_gr &&
+      m_target_instance->get_version() >=
+          k_mysql_communication_stack_initial_version) {
+    m_options.gr_options.communication_stack = kCommunicationStackMySQL;
+
+    // Verify if the allowlist is used when the communication stack is MySQL by
+    // default
+    if (!m_options.gr_options.ip_allowlist.is_null()) {
+      throw shcore::Exception::argument_error(shcore::str_format(
+          "Cannot use '%s' when the '%s' is '%s'",
+          m_options.gr_options.ip_allowlist_option_name.c_str(),
+          kCommunicationStack, kCommunicationStackMySQL));
+    }
+
+    // Validate localAddress if the communication stack is MySQL by default
+    if (!m_options.gr_options.local_address.is_null()) {
+      validate_local_address_option(
+          *m_options.gr_options.local_address,
+          m_options.gr_options.communication_stack.get_safe(),
+          m_target_instance->get_canonical_port());
+    }
+  }
+
   // Verify if the instance is running asynchronous
   // replication. Skip if 'force' is enabled.
   if (!m_options.force.get_safe()) {
@@ -256,7 +310,7 @@ void Create_cluster::prepare() {
         m_target_instance->descr().c_str());
   }
 
-  // If adopting, set the target_instance to the primary member of the group:.
+  // If adopting, set the target_instance to the primary member of the group:
   //
   // Adopting a cluster can be performed using any member of the group
   // regardless if it's a primary or a secondary. However, all the operations
@@ -264,7 +318,7 @@ void Create_cluster::prepare() {
   // group. We should not bypass GR's mechanism to avoid writes on the secondary
   // by disabling super_read_only. Apart from possible GTID inconsistencies, a
   // secondary will end up having super_read_only disabled.
-  if (m_options.adopt_from_gr) {
+  if (m_options.get_adopt_from_gr()) {
     m_target_instance = get_primary_member_from_group(m_target_instance);
   }
 
@@ -281,7 +335,7 @@ void Create_cluster::prepare() {
   }
 
   try {
-    if (!m_options.adopt_from_gr) {
+    if (!m_options.get_adopt_from_gr()) {
       // Check instance configuration and state, like dba.checkInstance
       // but skip if we're adopting, since in that case the target is obviously
       // already configured
@@ -310,7 +364,7 @@ void Create_cluster::prepare() {
       // Make sure the target instance does not already belong to a cluster.
       if (!m_retrying)
         mysqlsh::dba::checks::ensure_instance_not_belong_to_cluster(
-            *m_target_instance, m_target_instance);
+            m_target_instance, m_target_instance, {});
 
       // Get the address used by GR for the added instance (used in MD).
       m_address_in_metadata = m_target_instance->get_canonical_address();
@@ -321,6 +375,7 @@ void Create_cluster::prepare() {
       m_options.gr_options.local_address =
           mysqlsh::dba::resolve_gr_local_address(
               m_options.gr_options.local_address,
+              m_options.gr_options.communication_stack,
               m_target_instance->get_canonical_hostname(),
               m_target_instance->get_canonical_port(), !m_retrying, false);
 
@@ -345,16 +400,14 @@ void Create_cluster::prepare() {
     }
 
     // Determine the GR mode if the cluster is to be adopt from GR.
-    if (m_options.adopt_from_gr) {
+    if (m_options.get_adopt_from_gr()) {
       // Get the primary UUID value to determine GR mode:
       // UUID (not empty) -> single-primary or "" (empty) -> multi-primary
       std::string gr_primary_uuid =
           mysqlshdk::gr::get_group_primary_uuid(*m_target_instance, nullptr);
 
       m_options.multi_primary = gr_primary_uuid.empty();
-    }
-
-    if (!m_options.adopt_from_gr) {
+    } else {
       // Set the internal configuration object: read/write configs from the
       // server.
       m_cfg = mysqlsh::dba::create_server_config(
@@ -376,6 +429,16 @@ void Create_cluster::prepare() {
     }
     throw;
   }
+
+  // Check if the operation is being called from create_replica_cluster():
+  // if the Metadata belongs to a ClusterSet we can assume that
+  Cluster_metadata cluster_md;
+  if (m_metadata &&
+      m_metadata->get_cluster_for_server_uuid(
+          m_metadata->get_md_server()->get_uuid(), &cluster_md) &&
+      !cluster_md.cluster_set_id.empty()) {
+    m_create_replica_cluster = true;
+  }
 }
 
 void Create_cluster::log_used_gr_options() {
@@ -428,6 +491,11 @@ void Create_cluster::log_used_gr_options() {
     log_info("Using Group Replication auto-rejoin tries: %s",
              std::to_string(*m_options.gr_options.auto_rejoin_tries).c_str());
   }
+
+  if (!m_options.gr_options.communication_stack.is_null()) {
+    log_info("Using Group Replication Communication Stack: %s",
+             m_options.gr_options.communication_stack->c_str());
+  }
 }
 
 void Create_cluster::prepare_metadata_schema() {
@@ -443,24 +511,58 @@ void Create_cluster::prepare_metadata_schema() {
   mysqlsh::dba::prepare_metadata_schema(m_target_instance, false);
 }
 
-void Create_cluster::setup_recovery(Cluster_impl *cluster,
-                                    mysqlshdk::mysql::IInstance *target,
-                                    std::string *out_username) {
+void Create_cluster::create_recovery_account(
+    mysqlshdk::mysql::IInstance *target, Cluster_impl *cluster,
+    std::string *out_username) {
   // Setup recovery account for this seed instance, which will be used
   // when/if it needs to rejoin.
   std::string repl_account_host;
   mysqlshdk::mysql::Auth_options repl_account;
-  std::tie(repl_account, repl_account_host) =
-      cluster->create_replication_user(target);
 
-  if (out_username) *out_username = repl_account.user;
+  if (cluster) {
+    std::tie(repl_account, repl_account_host) =
+        cluster->create_replication_user(target);
+  } else {
+    repl_account_host = m_options.replication_allowed_host.empty()
+                            ? "%"
+                            : m_options.replication_allowed_host;
 
-  // Insert the recovery account on the Metadata Schema.
-  cluster->get_metadata_storage()->update_instance_repl_account(
-      target->get_uuid(), Cluster_type::GROUP_REPLICATION, repl_account.user,
-      repl_account_host);
+    repl_account.user = mysqlshdk::gr::k_group_recovery_user_prefix +
+                        std::to_string(m_target_instance->get_server_id());
 
-  // Set the GR replication (recovery) user.
+    log_info("Creating recovery account '%s'@'%s' for instance '%s'",
+             repl_account.user.c_str(), repl_account_host.c_str(),
+             m_target_instance->descr().c_str());
+
+    if (m_target_instance->user_exists(repl_account.user, repl_account_host)) {
+      mysqlsh::current_console()->print_note(shcore::str_format(
+          "User '%s'@'%s' already existed at instance '%s'. It will be "
+          "deleted and created again with a new password.",
+          repl_account.user.c_str(), repl_account_host.c_str(),
+          m_target_instance->descr().c_str()));
+      m_target_instance->drop_user(repl_account.user, repl_account_host);
+    }
+
+    auto target_version = m_target_instance->get_version();
+
+    bool clone_available_on_target =
+        target_version >=
+        mysqlshdk::mysql::k_mysql_clone_plugin_initial_version;
+
+    bool mysql_communication_stack_available_on_target =
+        target_version >= k_mysql_communication_stack_initial_version;
+
+    repl_account = mysqlshdk::gr::create_recovery_user(
+        repl_account.user, *m_target_instance, {repl_account_host}, {},
+        clone_available_on_target, false,
+        mysql_communication_stack_available_on_target);
+  }
+
+  if (out_username) {
+    *out_username = repl_account.user;
+  }
+
+  // Configure GR's recovery channel with the newly created account
   log_debug("Changing GR recovery user details for %s",
             target->descr().c_str());
 
@@ -473,10 +575,33 @@ void Create_cluster::setup_recovery(Cluster_impl *cluster,
         shcore::str_format("Error updating recovery credentials for %s: %s",
                            target->descr().c_str(), e.what()));
 
-    cluster->drop_replication_user_old(target);
+    cluster->drop_replication_user(target);
   }
 }
 
+void Create_cluster::store_recovery_account_metadata(
+    mysqlshdk::mysql::IInstance *target, const Cluster_impl &cluster) {
+  std::string repl_account_host = "%";
+  mysqlshdk::mysql::Auth_options repl_account;
+
+  shcore::Value allowed_host;
+  if (cluster.get_metadata_storage()->query_cluster_attribute(
+          cluster.get_id(), k_cluster_attribute_replication_allowed_host,
+          &allowed_host) &&
+      allowed_host.type == shcore::String &&
+      !allowed_host.as_string().empty()) {
+    repl_account_host = allowed_host.as_string();
+  }
+
+  repl_account.user = mysqlshdk::mysql::get_replication_user(
+      *target, mysqlshdk::gr::k_gr_recovery_channel);
+
+  // Insert the recovery account on the Metadata Schema.
+  cluster.get_metadata_storage()->update_instance_repl_account(
+      target->get_uuid(), Cluster_type::GROUP_REPLICATION, repl_account.user,
+      repl_account_host);
+}
+
 void Create_cluster::reset_recovery_all(Cluster_impl *cluster) {
   // Iterate all members of the group and reset recovery credentials
   auto console = mysqlsh::current_console();
@@ -494,7 +619,10 @@ void Create_cluster::reset_recovery_all(Cluster_impl *cluster) {
             *target, mysqlshdk::gr::k_gr_recovery_channel));
 
         std::string new_user;
-        setup_recovery(cluster, target.get(), &new_user);
+
+        create_recovery_account(target.get(), cluster, &new_user);
+        store_recovery_account_metadata(target.get(), *cluster);
+
         new_users.insert(new_user);
         return true;
       });
@@ -559,11 +687,11 @@ void Create_cluster::validate_local_address_ip_compatibility() const {
 
 shcore::Value Create_cluster::execute() {
   auto console = mysqlsh::current_console();
-  console->print_info("Creating InnoDB cluster '" + m_cluster_name + "' on '" +
+  console->print_info("Creating InnoDB Cluster '" + m_cluster_name + "' on '" +
                       m_target_instance->descr() + "'...\n");
 
-  // Common informative logging
-  if (m_options.adopt_from_gr) {
+  //  Common informative logging
+  if (m_options.get_adopt_from_gr()) {
     log_info(
         "Adopting cluster from existing Group Replication and using its "
         "settings.");
@@ -579,9 +707,9 @@ shcore::Value Create_cluster::execute() {
                                                     nullptr);
   }
 
-  if (*m_options.multi_primary && !m_options.adopt_from_gr) {
+  if (*m_options.multi_primary && !m_options.get_adopt_from_gr()) {
     console->print_info(
-        "The MySQL InnoDB cluster is going to be setup in advanced "
+        "The MySQL InnoDB Cluster is going to be setup in advanced "
         "Multi-Primary Mode. Consult its requirements and limitations in "
         "https://dev.mysql.com/doc/refman/en/"
         "group-replication-limitations.html");
@@ -593,7 +721,7 @@ shcore::Value Create_cluster::execute() {
   try {
     console->print_info("Adding Seed Instance...");
 
-    if (!m_options.adopt_from_gr) {
+    if (!m_options.get_adopt_from_gr()) {
       if (m_retrying && !m_options.dry_run) {
         // If we're retrying, make sure GR is stopped
         console->print_note("Stopping GR started by a previous failed attempt");
@@ -609,10 +737,52 @@ shcore::Value Create_cluster::execute() {
       // instance If the instance already has master_user set to this value when
       // we enter createCluster(), it means a previous attempt failed.
       // Note: this shouldn't be set if we're adopting
-      assert(!m_options.adopt_from_gr);
+      assert(!m_options.get_adopt_from_gr());
       mysqlshdk::mysql::create_indicator_tag(
           *m_target_instance, metadata::kClusterSetupIndicatorTag);
 
+      // When using the communicationStack 'MySQL' the recovery channel must be
+      // set-up before starting GR because GR requires that the recovery channel
+      // is configured in order to obtain the credentials information
+      if (m_options.gr_options.communication_stack.get_safe() ==
+          kCommunicationStackMySQL) {
+        // Create the Recovery account and configure GR's recovery channel.
+        // If creating a Replica Cluster, suppress the binary log otherwise
+        // we're creating an errant transaction in the Replica Cluster.
+        // When a standalone Cluster we must not suppress the binary log
+        // otherwise the transaction will never be replicated to the Cluster
+        // members
+
+        // Check if super_read_only is enabled. If so it must be disabled to
+        // create the account. This might happen if super_read_only is persisted
+        // and we're creating a Replica Cluster
+        if (m_target_instance->get_sysvar_bool("super_read_only").get_safe()) {
+          m_target_instance->set_sysvar("super_read_only", false);
+        }
+
+        std::string repl_account;
+
+        if (m_create_replica_cluster) {
+          mysqlshdk::mysql::Suppress_binary_log nobinlog(
+              m_target_instance.get());
+
+          create_recovery_account(m_target_instance.get(), nullptr,
+                                  &repl_account);
+        } else {
+          create_recovery_account(m_target_instance.get(), nullptr,
+                                  &repl_account);
+        }
+
+        // Drop the recovery account if GR fails to start
+        undo_list.push_front([=]() {
+          std::string repl_account_host =
+              m_options.replication_allowed_host.empty()
+                  ? "%"
+                  : m_options.replication_allowed_host;
+          m_target_instance->drop_user(repl_account, repl_account_host);
+        });
+      }
+
       // GR has to be stopped if this fails
       undo_list.push_front([this, console]() {
         log_info("revert: Stopping group_replication");
@@ -634,6 +804,9 @@ shcore::Value Create_cluster::execute() {
       });
       // Start GR before creating the recovery user and metadata, so that
       // all transactions executed by us have the same GTID prefix
+      // NOTE: When the communicationStack chosen is "MySQL", there's one
+      // transaction that will have a different GTID prefix that is the "CREATE
+      // USER" (see above)
       mysqlsh::dba::start_cluster(*m_target_instance, m_options.gr_options,
                                   m_options.multi_primary, m_cfg.get());
     }
@@ -676,7 +849,7 @@ shcore::Value Create_cluster::execute() {
     undo_list.push_front([&trx]() { trx.rollback(); });
 
     metadata->create_cluster_record(cluster_impl.get(),
-                                    m_options.adopt_from_gr);
+                                    m_options.get_adopt_from_gr());
 
     metadata->update_cluster_attribute(
         cluster_impl->get_id(), k_cluster_attribute_replication_allowed_host,
@@ -684,6 +857,12 @@ shcore::Value Create_cluster::execute() {
             ? shcore::Value("%")
             : shcore::Value(m_options.replication_allowed_host));
 
+    // Store the communicationStack in the Metadata as a Cluster capability
+    // TODO(miguel): build and add the list of allowed operations
+    metadata->update_cluster_capability(
+        cluster_impl->get_id(), kCommunicationStack,
+        m_options.gr_options.communication_stack.get_safe(), {});
+
     metadata->update_cluster_attribute(
         cluster_impl->get_id(), k_cluster_attribute_assume_gtid_set_complete,
         m_options.clone_options.gtid_set_is_complete ? shcore::Value::True()
@@ -706,7 +885,7 @@ shcore::Value Create_cluster::execute() {
     }
 
     // Insert instance into the metadata.
-    if (m_options.adopt_from_gr) {
+    if (m_options.get_adopt_from_gr()) {
       // Adoption from an existing GR group is performed after creating/updating
       // the metadata (since it is used internally by adopt_from_gr()).
       cluster_impl->adopt_from_gr();
@@ -733,7 +912,33 @@ shcore::Value Create_cluster::execute() {
             m_target_instance->get_connection_options());
       }
 
-      setup_recovery(cluster_impl.get(), m_target_instance.get());
+      // Create the recovery account and update the Metadata
+      // NOTE: If the Cluster is a REPLICA the account must be created at the
+      // PRIMARY Cluster too (create_recovery_account will create it at the MD
+      // server)
+      if (m_create_replica_cluster ||
+          m_options.gr_options.communication_stack.is_null() ||
+          m_options.gr_options.communication_stack.get_safe() ==
+              kCommunicationStackXCom) {
+        std::string repl_account;
+        create_recovery_account(m_target_instance.get(), cluster_impl.get(),
+                                &repl_account);
+
+        // Drop the recovery account if GR fails to start
+        undo_list.push_front([=]() {
+          std::string repl_account_host =
+              m_options.replication_allowed_host.empty()
+                  ? "%"
+                  : m_options.replication_allowed_host;
+          m_target_instance->drop_user(repl_account, repl_account_host);
+        });
+
+        store_recovery_account_metadata(m_target_instance.get(), *cluster_impl);
+      } else {
+        // The recovery account was already created, just updated the Metadata:
+        // Standalone cluster using MySQL comm stack
+        store_recovery_account_metadata(m_target_instance.get(), *cluster_impl);
+      }
     }
 
     // Handle the clone options
@@ -797,7 +1002,7 @@ shcore::Value Create_cluster::execute() {
                                        metadata::kClusterSetupIndicatorTag);
 
   std::string message =
-      m_options.adopt_from_gr
+      m_options.get_adopt_from_gr()
           ? "Cluster successfully created based on existing "
             "replication group."
           : "Cluster successfully created. Use "
