@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, 2021, Oracle and/or its affiliates.
+ * Copyright (c) 2016, 2022, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -129,7 +129,8 @@ void Cluster::init() {
          "?instance")
       ->cli();
   expose("switchToMultiPrimaryMode", &Cluster::switch_to_multi_primary_mode);
-  expose("setPrimaryInstance", &Cluster::set_primary_instance, "instance")
+  expose("setPrimaryInstance", &Cluster::set_primary_instance, "instance",
+         "?options")
       ->cli();
   expose("options", &Cluster::options, "?options")->cli();
   expose("setOption", &Cluster::set_option, "option", "value")->cli();
@@ -239,8 +240,7 @@ recovery process to finish and its verbosity level.
 @li memberSslMode: SSL mode used on the instance
 ${CLUSTER_OPT_IP_WHITELIST}
 ${CLUSTER_OPT_IP_ALLOWLIST}
-@li localAddress: string value with the Group Replication local address to be
-used instead of the automatically generated one.
+${CLUSTER_OPT_LOCAL_ADDRESS}
 @li groupSeeds: string value with a comma-separated list of the Group
 Replication peer addresses to be used instead of the automatically generated
 one. Deprecated and ignored.
@@ -301,16 +301,7 @@ ${CLUSTER_OPT_IP_ALLOWLIST_EXTRA}
 The localAddress and groupSeeds are advanced options and their usage is
 discouraged since incorrect values can lead to Group Replication errors.
 
-The value for localAddress is used to set the Group Replication system variable
-'group_replication_local_address'. The localAddress option accepts values in
-the format: 'host:port' or 'host:' or ':port'. If the specified value does not
-include a colon (:) and it is numeric, then it is assumed to be the port,
-otherwise it is considered to be the host. When the host is not specified, the
-default value is the value of the system variable 'report_host' if defined
-(i.e., not 'NULL'), otherwise it is the hostname value. When the port is not
-specified, the default value is the port of the target instance * 10 + 1. In
-case the automatically determined default port value is invalid (> 65535) then
-an error is thrown.
+${CLUSTER_OPT_LOCAL_ADDRESS_EXTRA}
 
 The groupSeeds option is deprecated as of MySQL Shell 8.0.28 and is ignored.
 'group_replication_group_seeds' is automatically set based on the current
@@ -403,6 +394,7 @@ The options dictionary may contain the following attributes:
 ${OPT_INTERACTIVE}
 ${CLUSTER_OPT_IP_WHITELIST}
 ${CLUSTER_OPT_IP_ALLOWLIST}
+${CLUSTER_OPT_LOCAL_ADDRESS}
 
 The password may be contained on the instance definition, however, it can be
 overwritten if it is specified on the options.
@@ -425,6 +417,11 @@ If memberSslMode is not specified AUTO will be used by default.
 
 ${CLUSTER_OPT_IP_ALLOWLIST_EXTRA}
 
+The localAddress is an advanced option and its usage is discouraged
+since incorrect values can lead to Group Replication errors.
+
+${CLUSTER_OPT_LOCAL_ADDRESS_EXTRA}
+
 @attention The ipWhitelist option will be removed in a future release.
 Please use the ipAllowlist option instead.
 )*");
@@ -461,7 +458,7 @@ void Cluster::rejoin_instance(
 
   // Rejoin the Instance to the Cluster
   m_impl->rejoin_instance(instance_def, options->gr_options,
-                          options->interactive(), false);
+                          options->interactive(), false, {});
 }
 
 REGISTER_HELP_FUNCTION(removeInstance, Cluster);
@@ -526,7 +523,7 @@ void Cluster::remove_instance(
   Scoped_instance_pool ipool(options->interactive(), auth_opts);
 
   // Remove the Instance from the Cluster
-  m_impl->remove_instance(instance_def, options->force, options->interactive());
+  m_impl->remove_instance(instance_def, *options);
 }
 
 REGISTER_HELP_FUNCTION(describe, Cluster);
@@ -799,6 +796,9 @@ not (false) to match the one being used by the cluster. By default, the
 metadata is not updated (false). Deprecated.
 @li upgradeCommProtocol: boolean. Set to true to upgrade the Group Replication
 communication protocol to the highest version possible.
+@li updateViewChangeUuid: boolean value used to indicate if the command should
+generate and set a value for Group Replication View Change UUID in the whole
+Cluster. Required for InnoDB ClusterSet usage.
 
 The value for addInstances and removeInstances is used to specify which
 instances to add or remove from the metadata, respectively. Both options accept
@@ -1044,6 +1044,7 @@ REGISTER_HELP_FUNCTION_TEXT(CLUSTER_SETPRIMARYINSTANCE, R"*(
 Elects a specific cluster member as the new primary.
 
 @param instance An instance definition.
+@param options Optional dictionary with options for the operation.
 
 @returns Nothing.
 
@@ -1056,6 +1057,14 @@ ${TOPIC_CONNECTION_MORE_INFO}
 
 The instance definition is mandatory and is the identifier of the cluster
 member that shall become the new primary.
+
+The options dictionary may contain the following attributes:
+
+@li runningTransactionsTimeout: integer value to define the time period, in
+seconds, that the primary election waits for ongoing transactions to complete.
+After the timeout is reached, any ongoing transaction is rolled back allowing
+the operation to complete.
+
 )*");
 
 /**
@@ -1064,15 +1073,19 @@ member that shall become the new primary.
  * $(CLUSTER_SETPRIMARYINSTANCE)
  */
 #if DOXYGEN_JS
-Undefined Cluster::setPrimaryInstance(InstanceDef instance) {}
+Undefined Cluster::setPrimaryInstance(InstanceDef instance,
+                                      Dictionary options) {}
 #elif DOXYGEN_PY
-None Cluster::set_primary_instance(InstanceDef instance) {}
+None Cluster::set_primary_instance(InstanceDef instance, dict options) {}
 #endif
 
-void Cluster::set_primary_instance(const Connection_options &instance_def) {
+void Cluster::set_primary_instance(
+    const Connection_options &instance_def,
+    const shcore::Option_pack_ref<cluster::Set_primary_instance_options>
+        &options) {
   assert_valid("setPrimaryInstance");
 
-  m_impl->set_primary_instance(instance_def);
+  m_impl->set_primary_instance(instance_def, *options);
 }
 
 REGISTER_HELP_FUNCTION(setOption, Cluster);
