@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2015, 2022, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -1234,21 +1234,23 @@ RowResult TableSelect::execute() {}
 #endif
 //@}
 shcore::Value TableSelect::execute(const shcore::Argument_list &args) {
-  std::unique_ptr<mysqlx::RowResult> result;
   args.ensure_count(0, get_function_name("execute").c_str());
+
+  std::shared_ptr<mysqlx::RowResult> result;
   try {
-    result.reset(new mysqlx::RowResult(safe_exec([this]() {
+    result = std::make_shared<mysqlx::RowResult>(safe_exec([this]() {
       update_limits();
       insert_bound_values(message_.mutable_args());
       return session()->session()->execute_crud(message_);
-    })));
+    }));
 
     update_functions(F::execute);
     if (!m_limit.is_null()) enable_function(F::offset);
   }
   CATCH_AND_TRANSLATE_CRUD_EXCEPTION(get_function_name("execute"));
 
-  return result ? shcore::Value::wrap(result.release()) : shcore::Value::Null();
+  return result ? shcore::Value::wrap(std::move(result))
+                : shcore::Value::Null();
 }
 
 void TableSelect::set_prepared_stmt() {
