@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015, 2021, Oracle and/or its affiliates.
+ * Copyright (c) 2015, 2022, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -29,7 +29,7 @@
 
 namespace shcore {
 
-PyObject *wrap(const std::shared_ptr<Value::Map_type> &map);
+py::Release wrap(const std::shared_ptr<Value::Map_type> &map);
 
 bool unwrap(PyObject *value, std::shared_ptr<Value::Map_type> *ret_object);
 
