@@ -30,6 +30,7 @@
 #include <functional>
 #include <stdexcept>
 #include <string>
+#include <string_view>
 #include <utility>
 #include <vector>
 
@@ -42,14 +43,14 @@ void clear_buffer(char *buffer, size_t size);
 void clear_buffer(std::string *buffer);
 
 /** Convert a copy of an ASCII string to uppercase and return */
-inline std::string str_upper(const std::string &s) {
+inline std::string str_upper(const std::string_view s) {
   std::string r(s);
   std::transform(r.begin(), r.end(), r.begin(), ::toupper);
   return r;
 }
 
 /** Convert a copy of an ASCII string to lowercase and return */
-inline std::string str_lower(const std::string &s) {
+inline std::string str_lower(const std::string_view s) {
   std::string r(s);
   std::transform(r.begin(), r.end(), r.begin(), ::tolower);
   return r;
@@ -74,14 +75,6 @@ struct Case_insensitive_comparator {
   }
 };
 
-inline bool str_caseeq(const char *a, const char *b) {
-#ifdef _WIN32
-  return ::_stricmp(a, b) == 0;
-#else
-  return ::strcasecmp(a, b) == 0;
-#endif
-}
-
 inline bool str_caseeq(const char *a, const char *b, size_t n) {
 #ifdef _WIN32
   return ::_strnicmp(a, b, n) == 0;
@@ -90,16 +83,13 @@ inline bool str_caseeq(const char *a, const char *b, size_t n) {
 #endif
 }
 
-inline bool str_caseeq(const std::string &a, const char *b) {
-  return str_caseeq(a.c_str(), b);
-}
-
-inline bool str_caseeq(const char *a, const std::string &b) {
-  return str_caseeq(a, b.c_str());
-}
-
-inline bool str_caseeq(const std::string &a, const std::string &b) {
-  return a.length() == b.length() && str_caseeq(a.c_str(), b.c_str());
+inline bool str_caseeq(std::string_view a, std::string_view b) {
+  if (a.size() != b.size()) return false;
+#ifdef _WIN32
+  return ::_strnicmp(a.data(), b.data(), a.size()) == 0;
+#else
+  return ::strncasecmp(a.data(), b.data(), a.size()) == 0;
+#endif
 }
 
 template <typename T, typename... Args>
@@ -108,27 +98,17 @@ bool str_caseeq_mv(T &&token, Args &&... args) {
 }
 
 /** Checks whether a string has another as a prefix */
-inline bool str_beginswith(const char *s, const char *prefix) {
-  return strncmp(s, prefix, strlen(prefix)) == 0;
-}
-
-inline bool str_beginswith(const std::string &s, const std::string &prefix) {
+inline bool str_beginswith(std::string_view s, std::string_view prefix) {
   return s.compare(0, prefix.length(), prefix) == 0;
 }
 
-inline bool str_ibeginswith(const char *s, const char *prefix) {
-#ifdef _WIN32
-  return ::_strnicmp(s, prefix, strlen(prefix)) == 0;
-#else
-  return strncasecmp(s, prefix, strlen(prefix)) == 0;
-#endif
-}
+inline bool str_ibeginswith(std::string_view s, std::string_view prefix) {
+  if (s.size() < prefix.size()) return false;
 
-inline bool str_ibeginswith(const std::string &s, const std::string &prefix) {
 #ifdef _WIN32
-  return ::_strnicmp(s.c_str(), prefix.c_str(), prefix.size()) == 0;
+  return ::_strnicmp(s.data(), prefix.data(), prefix.size()) == 0;
 #else
-  return strncasecmp(s.c_str(), prefix.c_str(), prefix.size()) == 0;
+  return strncasecmp(s.data(), prefix.data(), prefix.size()) == 0;
 #endif
 }
 
@@ -405,9 +385,8 @@ inline std::string str_join(
   return str_join(container.begin(), container.end(), sep, f);
 }
 
-std::string SHCORE_PUBLIC str_replace(const std::string &s,
-                                      const std::string &from,
-                                      const std::string &to);
+std::string SHCORE_PUBLIC str_replace(std::string_view s, std::string_view from,
+                                      std::string_view to);
 
 std::string SHCORE_PUBLIC bits_to_string(uint64_t bits, int nbits);
 std::pair<uint64_t, int> SHCORE_PUBLIC string_to_bits(const std::string &s);
@@ -434,7 +413,7 @@ std::string quote_string(const std::string &s, char quote);
  *
  * @return Unquoted string.
  */
-std::string unquote_string(const std::string &s, char quote);
+std::string unquote_string(std::string_view s, char quote);
 
 // Macro to turn a symbol into a string
 #define STRINGIFY(s) STRINGIFY_(s)
@@ -573,6 +552,12 @@ bool is_valid_utf8(const std::string &s);
  */
 std::string pctencode(const std::string &s);
 
+/**
+ * Generates a percent encoded string based on RFC-3986, but does not encode
+ * slashes.
+ */
+std::string pctencode_path(const std::string &s);
+
 /**
  * Decodes a string that is percent encoded based on RFC-3986
  */
