@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, 2021, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2022, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -101,8 +101,15 @@ class Auto_script_js : public Shell_js_script_tester,
       code = shcore::str_format("var __mysql_sandbox_port%i = %i;", i + 1,
                                 _mysql_sandbox_ports[i]);
       execute(code);
-      code = shcore::str_format("var __mysql_sandbox_gr_port%i = %i;", i + 1,
-                                _mysql_sandbox_ports[i] * 10 + 1);
+      // With 8.0.27, the GR Protocol Communication Stack became MySQL by
+      // default and localAddress is set to the server port by default
+      if (_target_server_version < mysqlshdk::utils::Version("8.0.27")) {
+        code = shcore::str_format("var __mysql_sandbox_gr_port%i = %i;", i + 1,
+                                  _mysql_sandbox_ports[i] * 10 + 1);
+      } else {
+        code = shcore::str_format("var __mysql_sandbox_gr_port%i = %i;", i + 1,
+                                  _mysql_sandbox_ports[i]);
+      }
       execute(code);
       code = shcore::str_format("var __mysql_sandbox_x_port%i = %i;", i + 1,
                                 _mysql_sandbox_ports[i] * 10);
@@ -220,10 +227,32 @@ class Auto_script_js : public Shell_js_script_tester,
 
     if (g_mysqld_path_variables && folder == "js_mixed_versions") {
       auto variables = shcore::str_split(g_mysqld_path_variables, ",");
+
+      std::string secondary_var_name{"MYSQLD_SECONDARY_SERVER_A"};
+
       for (const auto &variable : variables) {
-        std::string code = shcore::str_format(
-            "var %s = os.getenv('%s')", variable.c_str(), variable.c_str());
-        execute(code);
+        auto serverParts = shcore::str_split(variable, ";");
+        assert(serverParts.size() == 2);
+
+        auto &serverVersion = serverParts[0];
+        auto &serverPath = serverParts[1];
+
+        {
+          auto code =
+              shcore::str_format("var %s = os.getenv('%s')", serverPath.c_str(),
+                                 serverPath.c_str());
+          execute(code);
+        }
+
+        if (secondary_var_name.back() <= 'Z') {
+          auto code = shcore::str_format(
+              "var %s = { path: os.getenv('%s'), version: \"%s\" }",
+              secondary_var_name.c_str(), serverPath.c_str(),
+              serverVersion.c_str());
+          execute(code);
+
+          secondary_var_name.back()++;
+        }
       }
     }
 
