@@ -768,7 +768,6 @@ shell.connect(__sandbox_uri3);
 testutil.changeSandboxConf(__mysql_sandbox_port3, "report_host", hostname);
 testutil.restartSandbox(__mysql_sandbox_port3);
 shell.connect(__sandbox_uri1);
-c.rejoinInstance(__sandbox_uri3);
 testutil.waitMemberState(__mysql_sandbox_port3, "ONLINE");
 
 s = c.status();
@@ -780,7 +779,7 @@ EXPECT_EQ(hostname_ip+":"+__mysql_sandbox_port3, s["defaultReplicaSet"]["topolog
 row = session.runSql("select * from mysql_innodb_cluster_metadata.instances where mysql_server_uuid=?", [instance3_uuid]).fetchOne();
 EXPECT_EQ(hostname_ip+":"+__mysql_sandbox_port3, row.address);
 EXPECT_EQ(hostname_ip+":"+__mysql_sandbox_port3, row.instance_name);
-EXPECT_EQ( {"mysqlX": hostname_ip+":"+__mysql_sandbox_port3+"0", "grLocal": hostname_ip+":"+__mysql_sandbox_port3+"1", "mysqlClassic": hostname_ip+":"+__mysql_sandbox_port3}, JSON.parse(row.addresses));
+EXPECT_EQ( {"mysqlX": hostname_ip+":"+__mysql_sandbox_port3+"0", "grLocal": hostname_ip+":"+__mysql_sandbox_gr_port3, "mysqlClassic": hostname_ip+":"+__mysql_sandbox_port3}, JSON.parse(row.addresses));
 
 //@<> setPrimary is expected to throw b/c metadata doesn't match {VER(>=8.0.27)}
 EXPECT_THROWS(function(){c.setPrimaryInstance(__sandbox_uri3);}, `The instance 'localhost:${__mysql_sandbox_port3}' does not belong to the cluster: 'cluster'.`);
@@ -792,7 +791,7 @@ c.rescan();
 row = session.runSql("select * from mysql_innodb_cluster_metadata.instances where mysql_server_uuid=?", [instance3_uuid]).fetchOne();
 EXPECT_EQ(hostname+":"+__mysql_sandbox_port3, row.address);
 EXPECT_EQ(hostname+":"+__mysql_sandbox_port3, row.instance_name);
-EXPECT_EQ( {"mysqlX": hostname+":"+__mysql_sandbox_port3+"0", "grLocal": hostname_ip+":"+__mysql_sandbox_port3+"1", "mysqlClassic": hostname+":"+__mysql_sandbox_port3}, JSON.parse(row.addresses));
+EXPECT_EQ( {"mysqlX": hostname+":"+__mysql_sandbox_x_port3, "grLocal": hostname_ip+":"+__mysql_sandbox_gr_port3, "mysqlClassic": hostname+":"+__mysql_sandbox_port3}, JSON.parse(row.addresses));
 
 s = c.status();
 
@@ -817,6 +816,36 @@ s = c.status();
 EXPECT_EQ(undefined, s["defaultReplicaSet"]["topology"][hostname_ip+":"+__mysql_sandbox_port3]);
 EXPECT_EQ(hostname_ip+":"+__mysql_sandbox_port3, s["defaultReplicaSet"]["topology"]["hooray"]["address"]);
 
+//@<> Test communication protocol upgrade {VER(>=8.0)}
+
+// Downgrade the protocol version to 5.7.14
+session.runSql("SELECT group_replication_set_communication_protocol('5.7.14')");
+
+s = c.status();
+
+if (__version_num >= 80027) {
+    EXPECT_EQ(["Group communication protocol in use is version 5.7.14 but it is possible to upgrade to 8.0.27. Message fragmentation for large transactions and Single Consensus Leader can only be enabled after upgrade. Use Cluster.rescan({upgradeCommProtocol:true}) to upgrade."], s["defaultReplicaSet"]["clusterErrors"]);
+} else if (__version_num >= 80016 && __version_num < 80027) {
+    EXPECT_EQ(["Group communication protocol in use is version 5.7.14 but it is possible to upgrade to 8.0.16. Message fragmentation for large transactions can only be enabled after upgrade. Use Cluster.rescan({upgradeCommProtocol:true}) to upgrade."], s["defaultReplicaSet"]["clusterErrors"]);
+}
+
+EXPECT_NO_THROWS(function () {c.rescan({upgradeCommProtocol:1});});
+
+s = c.status();
+EXPECT_EQ(undefined, s["defaultReplicaSet"]["clusterErrors"]);
+
+// Downgrade the protocol version to 8.0.16
+if (__version_num >= 80027) {
+    session.runSql("SELECT group_replication_set_communication_protocol('8.0.16')");
+
+    s = c.status();
+    EXPECT_EQ(["Group communication protocol in use is version 8.0.16 but it is possible to upgrade to 8.0.27. Single Consensus Leader can only be enabled after upgrade. Use Cluster.rescan({upgradeCommProtocol:true}) to upgrade."], s["defaultReplicaSet"]["clusterErrors"]);
+
+    EXPECT_NO_THROWS(function () {c.rescan({upgradeCommProtocol:1});});
+
+    s = c.status();
+    EXPECT_EQ(undefined, s["defaultReplicaSet"]["clusterErrors"]);
+}
 
 //@ Finalize.
 cluster.disconnect();
