@@ -130,7 +130,7 @@ CHECK_CLUSTER_SET(session);
 // dryRun -> no-op
 EXPECT_DRYRUN(function(){cs.rejoinCluster("cluster2", {dryRun:1});}, __mysql_sandbox_port1);
 
-// this rejoin will have no errant transactions, but there will be GR view events
+// this rejoin will have no errant transactions
 cs.rejoinCluster("cluster2");
 
 CHECK_PRIMARY_CLUSTER([__sandbox_uri1, __sandbox_uri2, __sandbox_uri3], c1);
@@ -149,6 +149,47 @@ CHECK_PRIMARY_CLUSTER([__sandbox_uri1, __sandbox_uri2, __sandbox_uri3], c1);
 CHECK_REPLICA_CLUSTER([__sandbox_uri4, __sandbox_uri5, __sandbox_uri6], c1, c2);
 CHECK_CLUSTER_SET(session);
 
+//@<> rejoin cluster with extra GTID events that are view-change-events
+
+// Stop the CS replication channel
+session4.runSql("stop replica for channel 'clusterset_replication'");
+
+// Generate view change events in the replica Cluster
+session6.runSql("STOP group_replication");
+session6.runSql("START group_replication");
+
+// Rejoin the Cluster
+cs.rejoinCluster("cluster2");
+EXPECT_OUTPUT_CONTAINS("* Reconciling internally generated GTIDs");
+
+// Purge the binary logs from all members
+// BUG#34013718: reconciliation doesn't happen when binlogs purged from all members
+session4.runSql("flush binary logs");
+session5.runSql("flush binary logs");
+session6.runSql("flush binary logs");
+os.sleep(1);
+session4.runSql("purge binary logs before now(6)");
+session5.runSql("purge binary logs before now(6)");
+session6.runSql("purge binary logs before now(6)");
+
+// promoting cluster2 to primary should be OK
+EXPECT_NO_THROWS(function() { cs.setPrimaryCluster("cluster2"); } );
+
+testutil.waitMemberTransactions(__mysql_sandbox_port1, __mysql_sandbox_port4);
+
+CHECK_PRIMARY_CLUSTER([__sandbox_uri4, __sandbox_uri6], c2);
+CHECK_REPLICA_CLUSTER([__sandbox_uri1, __sandbox_uri2, __sandbox_uri3], c2, c1);
+CHECK_CLUSTER_SET(session);
+
+// promoting cluster1 back to primary
+EXPECT_NO_THROWS(function() { cs.setPrimaryCluster("cluster1"); } );
+
+testutil.waitMemberTransactions(__mysql_sandbox_port4, __mysql_sandbox_port1);
+
+CHECK_PRIMARY_CLUSTER([__sandbox_uri1, __sandbox_uri2, __sandbox_uri3], c1);
+CHECK_REPLICA_CLUSTER([__sandbox_uri4, __sandbox_uri6], c1, c2);
+CHECK_CLUSTER_SET(session);
+
 //@<> rejoin partially offline cluster
 
 invalidate_cluster(c2, c1);
@@ -293,14 +334,19 @@ session6.runSql("change replication source to source_password='bogus' for channe
 
 cs.rejoinCluster("cluster2");
 
-c2.setPrimaryInstance(__sandbox_uri6);
+EXPECT_NO_THROWS(function(){c2.setPrimaryInstance(__sandbox_uri6);});
 wait_channel_ready(session6, __mysql_sandbox_port1, "clusterset_replication");
 
-cs.status({extended:1});
+status = cs.status({extended:1});
+EXPECT_EQ("PRIMARY", status["clusters"]["cluster2"]["topology"][`${hostname}:${__mysql_sandbox_port6}`]["memberRole"])
 
-c2.setPrimaryInstance(__sandbox_uri4);
+c2 = dba.getCluster();
+EXPECT_NO_THROWS(function(){c2.setPrimaryInstance(__sandbox_uri4);});
 wait_channel_ready(session4, __mysql_sandbox_port1, "clusterset_replication");
 
+status = c2.status({extended:1});
+EXPECT_EQ("PRIMARY", status["defaultReplicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port4}`]["memberRole"])
+
 //@<> rejoinCluster primary cluster after rebooting it
 // see Bug #33166390 CLUSTERSET: when doing rejoincluster, a member is kicked out of GR
 
@@ -321,14 +367,21 @@ session2 = mysql.getSession(__sandbox_uri2);
 session3 = mysql.getSession(__sandbox_uri3);
 
 shell.connect(__sandbox_uri1);
-c1 = dba.rebootClusterFromCompleteOutage();
+
+// Unable to rejoin instances since this cluster is INVALIDATED
+EXPECT_THROWS_TYPE(function(){dba.rebootClusterFromCompleteOutage("cluster1", {rejoinInstances: [__endpoint2, __endpoint3]});}, "Dba.rebootClusterFromCompleteOutage: removeInstances and/or rejoinInstances options cannot be used for Invalidated Clusters", "ArgumentError");
+
+c1 = dba.rebootClusterFromCompleteOutage("cluster1");
+
+cs.rejoinCluster("cluster1");
+
+// Rejoin the instances now
+c1 = dba.getCluster();
 c1.rejoinInstance(__sandbox_uri2);
 testutil.waitMemberState(__mysql_sandbox_port2, "ONLINE");
 c1.rejoinInstance(__sandbox_uri3);
 testutil.waitMemberState(__mysql_sandbox_port3, "ONLINE");
 
-cs.rejoinCluster("cluster1");
-
 cs.status({extended:1});
 
 CHECK_REPLICA_CLUSTER([__sandbox_uri1, __sandbox_uri2, __sandbox_uri3], c2, c1);
