@@ -5,6 +5,7 @@
 // be tested everywhere else.
 
 //@<> INCLUDE clusterset_utils.inc
+//@<> INCLUDE dba_utils.inc
 
 // Negative tests based on environment and params
 //-----------------------------------------------
@@ -62,8 +63,8 @@ var __cluster_id = session1.runSql("select cluster_id from mysql_innodb_cluster_
 var __cluster_group_name = session4.runSql("select @@group_replication_group_name").fetchOne()[0];
 session1.runSql("INSERT INTO mysql_innodb_cluster_metadata.v2_routers (address, product_name, router_name) VALUES ('foo', 'MySQL Router', 'router_primary')");
 session1.runSql("INSERT INTO mysql_innodb_cluster_metadata.v2_routers (address, product_name, router_name) VALUES ('bar', 'MySQL Router', 'router_secondary')");
-session1.runSql("UPDATE mysql_innodb_cluster_metadata.v2_routers SET attributes = JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(IF(attributes IS NULL, '{}', attributes), '$.RWEndpoint', '6446'), '$.ROEndpoint', '6447'), '$.RWXEndpoint', '6448'), '$.ROXEndpoint', '6449'), '$.MetadataUser', 'router'), options = JSON_SET(IF(options IS NULL, '{}', options), '$.target_cluster', ?), version = '8.0.25', cluster_id = ? WHERE router_id = 1", [__cluster_group_name, __cluster_id]);
-session1.runSql("UPDATE mysql_innodb_cluster_metadata.v2_routers SET attributes = JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(IF(attributes IS NULL, '{}', attributes), '$.RWEndpoint', '6446'), '$.ROEndpoint', '6447'), '$.RWXEndpoint', '6448'), '$.ROXEndpoint', '6449'), '$.MetadataUser', 'router'), options = JSON_SET(IF(options IS NULL, '{}', options), '$.target_cluster', ?), version = '8.0.25', cluster_id = ? WHERE router_id = 2", [__cluster_group_name, __cluster_id]);
+session1.runSql("UPDATE mysql_innodb_cluster_metadata.v2_routers SET attributes = JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(IF(attributes IS NULL, '{}', attributes), '$.RWEndpoint', 'mysql.sock'), '$.ROEndpoint', '6447'), '$.RWXEndpoint', ''), '$.ROXEndpoint', '6449'), '$.MetadataUser', 'router'), options = JSON_SET(IF(options IS NULL, '{}', options), '$.target_cluster', ?), version = '8.0.25', cluster_id = ? WHERE router_id = 1", [__cluster_group_name, __cluster_id]);
+session1.runSql("UPDATE mysql_innodb_cluster_metadata.v2_routers SET attributes = JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(IF(attributes IS NULL, '{}', attributes), '$.RWEndpoint', '6446'), '$.ROEndpoint', 'mysqlro.sock'), '$.RWXEndpoint', '6448'), '$.ROXEndpoint', ''), '$.MetadataUser', 'router'), options = JSON_SET(IF(options IS NULL, '{}', options), '$.target_cluster', ?), version = '8.0.25', cluster_id = ? WHERE router_id = 2", [__cluster_group_name, __cluster_id]);
 
 EXPECT_THROWS_TYPE(function(){clusterset.removeCluster("replicacluster"); }, "The Cluster 'replicacluster' is an active Target Cluster for Routing operations.", "MYSQLSH");
 EXPECT_OUTPUT_CONTAINS("ERROR: The following Routers are using the Cluster 'replicacluster' as a target cluster: [foo::router_primary, bar::router_secondary]. Please ensure no Routers are using the cluster as target with .setRoutingOption()");
@@ -75,6 +76,7 @@ session1.runSql("UPDATE mysql_innodb_cluster_metadata.routers SET options = json
 CHECK_GTID_CONSISTENT(session1, session4);
 
 EXPECT_NO_THROWS(function() {clusterset.removeCluster("replicacluster", {timeout: 0}); });
+EXPECT_OUTPUT_CONTAINS("* Reconciling internally generated GTIDs...");
 
 CHECK_ROUTER_OPTIONS_REMOVED_CLUSTER(session1);
 
@@ -120,7 +122,42 @@ EXPECT_EQ("OFFLINE", session4.runSql("select member_state from performance_schem
 
 CHECK_REMOVED_CLUSTER([__sandbox_uri4, __sandbox_uri6], cluster, "replicacluster");
 
-//<> Remove Cluster but with limited sync timeout
+//@<> Re-create the Replica Cluster on the primary instance (GTID-SET should have been reconciled regarding VCLEs).
+var replica_vcle_primary;
+EXPECT_NO_THROWS(function() {replica_vcle_primary = clusterset.createReplicaCluster(__sandbox_uri4, "replica_vcle_primary"); });
+
+CHECK_PRIMARY_CLUSTER([__sandbox_uri1], cluster);
+CHECK_REPLICA_CLUSTER([__sandbox_uri4], cluster, replica_vcle_primary);
+CHECK_CLUSTER_SET(session);
+
+EXPECT_NO_THROWS(function() {clusterset.removeCluster("replica_vcle_primary", {timeout: 0}); });
+EXPECT_OUTPUT_CONTAINS("* Reconciling internally generated GTIDs...");
+
+//@<> Re-create the Replica Cluster on a secondary instance (GTID-SET should have been reconciled regarding VCLEs)
+var replica_vcle_secondary;
+EXPECT_NO_THROWS(function() {replica_vcle_secondary = clusterset.createReplicaCluster(__sandbox_uri6, "replica_vcle_secondary"); });
+
+CHECK_PRIMARY_CLUSTER([__sandbox_uri1], cluster);
+CHECK_REPLICA_CLUSTER([__sandbox_uri6], cluster, replica_vcle_secondary);
+CHECK_CLUSTER_SET(session);
+
+EXPECT_NO_THROWS(function() {clusterset.removeCluster("replica_vcle_secondary", {timeout: 0}); });
+EXPECT_OUTPUT_CONTAINS("* Reconciling internally generated GTIDs...");
+
+//@<> Re-create the Replica Cluster on a single-member Cluster (GTID-SET should have been reconciled regarding VCLEs).
+CHECK_REMOVED_CLUSTER([__sandbox_uri4], cluster, "replica_vcle_primary");
+
+EXPECT_NO_THROWS(function() {replica_vcle_primary = clusterset.createReplicaCluster(__sandbox_uri4, "replica_vcle_primary"); });
+
+CHECK_PRIMARY_CLUSTER([__sandbox_uri1], cluster);
+CHECK_REPLICA_CLUSTER([__sandbox_uri4], cluster, replica_vcle_primary);
+CHECK_CLUSTER_SET(session);
+
+// Remove the cluster to clean-up for the proceeding tests
+EXPECT_NO_THROWS(function() {clusterset.removeCluster("replica_vcle_primary", {timeout: 0}); });
+EXPECT_OUTPUT_CONTAINS("* Reconciling internally generated GTIDs...");
+
+//@<> Remove Cluster but with limited sync timeout
 var replicacluster2 = clusterset.createReplicaCluster(__sandbox_uri5, "replicacluster2", {recoveryMethod: "clone"});
 
 session1 = mysql.getSession(__sandbox_uri1);
@@ -196,6 +233,15 @@ EXPECT_OUTPUT_CONTAINS("WARNING: The Cluster 'replicacluster' appears to have be
 
 EXPECT_NO_THROWS(function() {c = dba.getCluster(); });
 
+// Dissolve the Cluster and verify all accounts and metadata are dropped (BUG#33239404)
+
+// Verify that the member actions are reset to the defaults too. The scenario on which the member actions wouldn't be reset is the one on which a Cluster is removed from a ClusterSet using the force option because it's unreachable. In this test-suite we cannot do that and since removeCluster() can contact the cluster to be removed it will reset the member actions. So to simulate that, we manually change the values of the member actions
+session4.runSql("SELECT group_replication_disable_member_action('mysql_start_failover_channels_if_primary', 'AFTER_PRIMARY_ELECTION')");
+session4.runSql("SELECT group_replication_disable_member_action('mysql_disable_super_read_only_if_primary', 'AFTER_PRIMARY_ELECTION')");
+
+c.dissolve();
+CHECK_DISSOLVED_CLUSTER(session);
+
 reset_instance(session4);
 
 //@<> Dissolve cluster that was the primary and got invalidated
@@ -222,6 +268,8 @@ EXPECT_OUTPUT_CONTAINS("WARNING: The Cluster 'replicacluster' appears to have be
 //@<> dissolve invalidated primary cluster with the handle from the reboot
 // (Bug#33166307)
 rc.dissolve();
+// Dissolve the Cluster and verify all accounts and metadata are dropped (BUG#33239404)
+CHECK_DISSOLVED_CLUSTER(session);
 
 reset_instance(session4);
 
