@@ -205,6 +205,21 @@ function hasOciEnvironment(context) {
   return true;
 }
 
+function hasAwsEnvironment() {
+  const variables = ['MYSQLSH_S3_BUCKET_NAME'];
+  const missing = [];
+  for (const variable of variables) {
+    if (!defined(function(){eval(variable)})) {
+      missing.push(variable);
+    }
+  }
+  if (missing.length) {
+    println(`Missing AWS Variables: ${missing}`);
+    return false;
+  }
+  return true;
+}
+
 
 function hasAuthEnvironment(context) {
   if (['LDAP_SIMPLE', 'LDAP_SASL', 'LDAP_KERBEROS', 'KERBEROS', 'FIDO'].indexOf(context) == -1) {
@@ -1330,6 +1345,19 @@ function EXPECT_SHELL_LOG_CONTAINS(text) {
   }
 }
 
+function EXPECT_SHELL_LOG_CONTAINS_COUNT(text, count) {
+  if (!(typeof count === 'number')) {
+    throw Error('"count" argument must be a number.');
+  }
+  var log_path = testutil.getShellLogPath();
+  var match_list = testutil.grepFile(log_path, text);
+  if (match_list.length !== count) {
+    var log_out = testutil.catFile(log_path);
+    var context = "<b>Context:</b> " + __test_context + "\n<red>Missing log output:</red> " + text + "\n<yellow>Actual log output:</yellow> " + log_out;
+    testutil.fail(context);
+  }
+}
+
 function EXPECT_SHELL_LOG_NOT_CONTAINS(text) {
   var log_path = testutil.getShellLogPath();
   var match_list = testutil.grepFile(log_path, text);
@@ -1465,8 +1493,15 @@ function ClusterScenario(ports, create_cluster_options, sandboxConfiguration) {
     if (!create_cluster_options.hasOwnProperty("gtidSetIsComplete")) {
       create_cluster_options["gtidSetIsComplete"] = true;
     }
+    if (testutil.versionCheck(__version, ">=", "8.0.27") && !create_cluster_options.hasOwnProperty("communicationStack")) {
+      create_cluster_options["communicationStack"] = "XCOM";
+    }
   } else {
-    create_cluster_options = { gtidSetIsComplete: true };
+    if (testutil.versionCheck(__version, ">=", "8.0.27")) {
+      create_cluster_options = { gtidSetIsComplete: true, communicationStack: "XCOM" };
+    } else {
+      create_cluster_options = { gtidSetIsComplete: true };
+    }
   }
 
   this.cluster = dba.createCluster("cluster", create_cluster_options);
